/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlUnop.h"
#include "HvControlIf.h"
#include "HvControlCast.h"
#include "HvControlSlice.h"
#include "HvControlPack.h"
#include "HvSignalPhasor.h"
#include "HvControlTabhead.h"
#include "HvControlRandom.h"
#include "HvSignalDel1.h"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvSignalLine.h"
#include "HvSignalTabwrite.h"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvSignalTabread.h"
#include "HvSignalRPole.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_oFcUla5F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LlAA3JdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_RyaEcH5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_dwyDRD7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gMEjjhnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GGwcz9hI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_d03YQtdA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cUkoo3aw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EhpcMKyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ml9wlwsm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tjI0lPtQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Yff6HiTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_V7BAbTyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_eoQHsb6N_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_UGhGWVSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5PNildp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7fX3MJLe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mNb9Ca16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZKt1K8jI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AzAYHMFy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eQitHZk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EMI6E57Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QWAad5vj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_liDFnr6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jvJOZKyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vjFIRdir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ngSH3RSW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eXyPMiNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_faOQpRZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MOXoG7ib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ADsGgHrd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DEQEjUaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_in4MfCTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RnVREVOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T50daCct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M1rYzLn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hGhpI6Tr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yulHe7j1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IIT4RGcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DBdm3h8H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bxkg0BuH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DzBN6v4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_glJRVYDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v8G3wTYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5su4ELor_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_H2zCWmrL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KvUSitgh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ttId421T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bvbpFePm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EQ16q4I1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jvhb1jic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_isGtmPjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lSjhJZX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZcrcqhSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_E5KZAY6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IxBcsGYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8cSaXQvC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CcTg1iOf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DWFq7eR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yyITAWYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w53GIKJd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j2P4WAWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gz99z59u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hAj0ddyj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_zs5MYwzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_XDHsTwhb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_hsSGXTKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_InBuZaVu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ml155X1x_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_D13TjngW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_skSgcmfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Opzsexs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hYPemNXj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NYgwUA9N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uKk4rjgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wj1TQHDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9CCk6Sfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aR8oMNMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_KUtG2gVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o1xSVXBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gXfmEj9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FM1utm2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ofTVmWd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZPpFgXKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_rfKaknlM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vs4tNmww_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_exoHZufZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ApNNQMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HLYQyFoM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BvgWrgNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x2JHfmLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pl9UvwsG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lcDHjdX3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x37lPDjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vZu3hYay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CG7pfxN8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xpd0gLag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_gjCYvMPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4J36Pha6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mX0ykAyL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7JsNZ5tk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oja5cqE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_y9WDKF9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_WAVAKt7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z5dCco2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IbxZ8bDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_urmdW32S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lL3GT6DJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qic1OfM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uzURYZLZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FnSVR0qW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S1UmaDov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pdHaFB4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rz37IN2V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bh23WgNV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WfkzBpxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_5OxP1yx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bmcuX9tC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UVoXa25c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v04riKtU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FBWcFVzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LOL15Bwx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_JnCW7j4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uye8cHGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U0nNxuGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IVgJgAah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bR2Eaohh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LTGK3cmF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tvhULVNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EDJoFIxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P2PnV67D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bg0K1gag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gp1lA5TZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4sFF5IF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h86lkzcI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_2YpONAO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oJpjTkCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8O86S0jU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0jjqNT8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_jBgQgC7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_M15XfGBG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ftzb4YEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ohrPUjUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dr7FrhVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UJ8WubBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OI9PMetC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j6H4gNHB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UMkn7Gst_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mJoixUED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gOuceqPu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_msNgmQPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IvcHvN1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bVT6SqqL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HdpPqcsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SlyPvEj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wwWkqvVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oklNCsq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pIOQSB4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5CRZiLnY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_nhARv1Zn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_oNMFCw27_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ivFRFh1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rpVIUfZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KDwJnFBH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mjIcPFqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QwRyGczu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vholXeaP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kxyBg3FY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_N6B8zrOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GeJzDG5D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bztv2R9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_o9e3fX1X_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_AgT5wfJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_XWWQ7oGZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KwjrBy5p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7MXEJbDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pIS3EiDQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HhmnTaTN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oIeEYTO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s6yTooCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qN5kBhI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DGc7WLW1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Q96iqBnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5BnR4jW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2kZV8iZf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_NSuphcQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_a8GQeZi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UWRYTSUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AGi8B3zm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9DacwJqY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7nJSwRtY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Og7stbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1YH6eOnt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iFJI3Kgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_O76dTM6z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_J71nXzoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VZmevt2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wpeCK0pJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_id5wskjk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_It44TaoQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5qgaEAOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u9FrnO4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mSiYMOpj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3swIUXqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MDYnPVnB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wYkL9g4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_F7rUmkZo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_sGtGAT5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kfHJG2Fb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6GHiMtMt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_97QunPUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9feAbdYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LhOw3dXY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6cUwqBnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o099PLNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tpDLLMNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_on3TyeH1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rm3EdkBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AmVVwcC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DX20MxIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_irzKSqgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_euDv1hrK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cAYmo345_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SEFcjWG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y1JvNlyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_db0Yzvsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V9Gqw3pJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o0rLWBM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nFzYOUkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_krBgENcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kdszcoJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Hx2fA0P0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_OVr7l9oA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_GsOiTsvz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7myNbLIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Kx510FL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s98bLsjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o1OK6hC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mnYfuoUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ef83e8v1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_vTB1GvGl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5XT5VzgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0NMy7ZER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vVy3wVAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xQBRn5in_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_w5qZvUOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_SUZKXQRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Vaejsez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LdiZ4E2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7aZpItSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CHsqBbgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lc0jC7k9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mdM7ZhzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qLKBPB8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MeDhfnTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8UKK8mDT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AD06blM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eVDTi0Oy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vYnhVugB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zRaeG298_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eBR2VaA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LzDoLlnR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_E1FhQp3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OawvKkDw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_8yp5mgRT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LgT9iNqQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TFGgzjjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V4WcTCrv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LbxpCrEE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wn2TWMrF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wCXvfFFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wMgi8VXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_q10hbw3a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O3lnn6v0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hNM3IvyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_La2uLvsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ct1dScD8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_jMxFHuA2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_uZ6SVxqP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BCS7E3xj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_adJoWq4D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pUg5ZQcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CnUQzsHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GVRBM0cy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q7ZvRj1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ycO7TZs1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RHuFHAHI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OsZOvghF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5EzqO2SM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zjHWK5Xq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7U7fHh18_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g12qX40I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lGSnF6lx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_C9kd8RNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UUF0djwA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jVmI32QN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_9uJWxJbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_um2wrYRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_otJwFdDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bRF8Ehc7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ccm0fvQG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XaenVeVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_orNIkNm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gu6BmauM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_DOCSSkCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1bLOa9nA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_l2OgOaDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y8QvfIRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_r36RCa9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rR5NMt5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Mn2G4XeJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pZNctJiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2YTnB5Jh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wywqE2ZD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lujYhyRQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k1Z970Ya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YxMf0d4c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ENHgf9YU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZNkJsEZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rINVXmCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KNQZ5SiV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pbcN7Zyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cg8hoEC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gfIS0wn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UQVsQKHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5Kaw9835_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SwNNDQLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9dMju0hn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_9PLWmVqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_o4jZZY1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EHX3G1q0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QMeDDV2t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_haqlNkYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vm05650M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c3FpKKaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c1WRNr3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Xsz7uXJG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OT7ONSHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BJCvR6zk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TnoMnGNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_m6MlFbcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Z9eL5IlI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_pJhzhhBS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R2ptISsU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YAO6dyUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NKgygMKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BeheXBFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3J2OsxUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NL7eNQ3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fhdyTPPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JjQPOEEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lkoMmkKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_taqbBcHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lwuDu1vN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AtMNOY6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_psRka7U7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HXgF0UJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3iokE1wj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_n5JwE6Ok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LgppBygD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_U3kIWgHj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_EReTiHZ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TNZSoy1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kb6uA85l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w45ck0Tk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WvERWzjF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YESWz8fi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OAUtsu8H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_owRzuOw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q7sfYPHq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xeao7Nta_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZHvubGhI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SnsW5H9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hLdIvfws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_m8BHiEq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LYeXtCSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZsrADDtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KcNFhBYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9j9ZYz4Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HHNCeKsj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xZwyl3Xn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_edFq261l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aD2AimRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iY2aBVYO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6QWuWGDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eLxGKmcV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ev1vnmWG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_imOFFq9i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xJf7gCcY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CiaqsZkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_g6RmIu5F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8irHC4iA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_2gVCepuW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_548ftrN1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_btL4vmv9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zyzVqeCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wZks5pNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hlfIpeww_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_59CGREoo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Aw04N9ZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_wTppF3lG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r2owkYnT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nZcejjPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zQ2cLko9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sYXkKMwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h0pbf47T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_swWfKNoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hA6hjOx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wRKdrJso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wm4O0sL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eOqZaPFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B7Hcrs0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9orDBQHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l7sjOE6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PIH8zAQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N8cFVLAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SqGIEkLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ia3OQ22P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DLad9U8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_foaqfjHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Cfy6Ph7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_t38m1xB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LRvFyzdq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5vu8sjKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Fu4XRyAk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DoNxcx1a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N3WAPR2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bfcpV2CX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T9uD0XfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KuwH7BgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nFAoXcHN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oA9LNXyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ydDh4amu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_egIPm4cP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3cCjnbrL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ufAc4CBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zZq72oqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jk1c28G6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HogPvksm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Dx7YwDn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lLfICOrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z9t159zu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wT1NZE0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7nCWqV70_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KnrTls2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yT03D8DI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DGM0sPHw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hcIoNgSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_96v8FBqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EjZTNPEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LTvE2itu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xhZ7Yu8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mi3gSZdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AvrTX39w_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1D5gvrUH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kDgwXg2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nnIdO4Mn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zOO5N3WU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aa8uhMDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4IQTVe6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EzZ8HkiG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7fgd1N8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sJfkHgvc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AMVmFkpT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4VnwJYoe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DFjlbVKY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_97yrK6bs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Fv0GE5Ln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZMEl0VjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jxb8NEYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JuJVwthd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DVS5u9cE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xS5fJ2jF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QJFEO1jK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_SWC0eQZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_hb1HOJja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9SPw92FM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_caWcDoSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_APOBV94N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YheuaIVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vrqAeSrv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QseHwqLK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_vd7LwTv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EDM8Qs2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1ucYamnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PPZCHPaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3LHNw9qv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DKbBTw0s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_OJBXKnEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a4fXsdX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kPO9Qomq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fsrtILvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZonIt3HC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_stR0Jm2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3b3WS7IW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KRQ2gb1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JFPihXUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6sBujWn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DKqyMYbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W0HMG76r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oO4lgoyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6gfRPZ2h_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_jZ5NsYSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nRVBSSSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JMfHzZyn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_dmY2znvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qZG9sv45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RAlphUC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uc9nvINl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MLXTCCNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Mkw3vVGY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_tvq4kPHr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_WddMZsxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TQBz5o43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NxCehDgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yzhbuYPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nGWB7G2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Ayj8t99t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IbyA0xbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hbb79JyR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_R23f0Hwx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yLCWoWTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_lrucTbd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_V4PjMotn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tSIvkysO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7AMyunAZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Rrrid1ck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3sK9qNLL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_awkDN10A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DR0Ynkbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zVNMz1Kh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AZEwPb2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TmBM4xcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JH1UhyZK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LsaiPGyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sN5DYtHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3vput0P1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GXwbNZiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bRTnzPrl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_THERKaV0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZx4uLHH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_niM06KQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ctL4CrjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ypvm3vqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YIrWeIx3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lo6mqpJN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IfEbSbqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0iEtEzrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_INkvLTn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TaNeec5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IfQp8ZHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PH5Zkxzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g5CLYQOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SfEP95Wl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X4pitM90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4ZmIKL4f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LQJ69bOY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_50rgpKrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MYVfFUYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OSpDxYWs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2JFkrG7e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gRScYxnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jvRWF5HR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_se8z84Pb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ib7EIMIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MdKI7wIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h4O7xYPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nm3QxKp9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NaZ8a1zZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6JNOsG5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gcLRhZEQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OBU4B7X6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q4LhFi8o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JOrTeNJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xvlt9p8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z7K4L2xC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OjQqrW6q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VvAMzdwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zd83rg6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y8ZXzpPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2HiEziAl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1O1F6qTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DnSMCQa8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_G1Ndn83f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DVMAavCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_S0v48UNk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cOGbNAD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JcH5wWHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Nd4IY5Nu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GzmhsDvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pkNWiGW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_azvQhyOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_thjm6SAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_977bYG3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PhilGpqx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aDsVRz9E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WcE6IlTt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k8AIPn6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Na18ZR6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cRd0ECzu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pZFu88rQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0YA6dVWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TaQxwRN7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eacOeBD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xscYC6H7_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_7HVtj4CL;
  SignalLine sLine_HVPAUopZ;
  SignalLine sLine_h8v9UHnn;
  SignalTabhead sTabhead_ftU7Uwc5;
  SignalTabread sTabread_JsBf97q1;
  SignalTabread sTabread_UR9PZRT4;
  SignalTabhead sTabhead_KEGHBg61;
  SignalTabread sTabread_CvNN9v6O;
  SignalTabread sTabread_Lb5hipas;
  SignalTabwrite sTabwrite_PwcRmY1B;
  SignalRPole sRPole_Z8H8AxIY;
  SignalDel1 sDel1_pKOIkqKp;
  SignalTabread sTabread_OJBXKnEe;
  SignalTabwrite sTabwrite_R7yICHDe;
  SignalTabread sTabread_rfKaknlM;
  SignalRPole sRPole_vxZVhBLt;
  SignalLine sLine_oTevwxgp;
  SignalLine sLine_m1gS2Xca;
  SignalTabread sTabread_SUZKXQRN;
  SignalTabread sTabread_uZ6SVxqP;
  SignalTabread sTabread_Mn2G4XeJ;
  SignalTabread sTabread_pJhzhhBS;
  SignalTabread sTabread_swWfKNoP;
  SignalTabread sTabread_m8BHiEq3;
  SignalTabwrite sTabwrite_NZZRa13l;
  SignalTabwrite sTabwrite_AsxBkHKU;
  SignalTabwrite sTabwrite_8bB1UpFy;
  SignalTabwrite sTabwrite_EOxuAuIY;
  SignalTabwrite sTabwrite_KzcEh0cu;
  SignalTabwrite sTabwrite_JxQ4H07J;
  SignalTabread sTabread_WAVAKt7r;
  SignalRPole sRPole_aJ7GvkAJ;
  SignalTabread sTabread_JnCW7j4M;
  SignalRPole sRPole_DV4TeETt;
  SignalTabread sTabread_ftzb4YEe;
  SignalRPole sRPole_uOavXcxN;
  SignalTabwrite sTabwrite_9tYqz89q;
  SignalTabwrite sTabwrite_vtASE6W0;
  SignalTabwrite sTabwrite_Y16JGJ4M;
  SignalTabwrite sTabwrite_1dxgHgP1;
  SignalLine sLine_azXGJ5Db;
  ControlVar cVar_oFcUla5F;
  ControlVar cVar_LlAA3JdI;
  ControlPack cPack_RyaEcH5w;
  ControlBinop cBinop_gMEjjhnb;
  ControlVar cVar_GGwcz9hI;
  ControlPack cPack_d03YQtdA;
  ControlVar cVar_cUkoo3aw;
  ControlVar cVar_EhpcMKyv;
  ControlDelay cDelay_Yff6HiTU;
  ControlDelay cDelay_V7BAbTyf;
  ControlBinop cBinop_UGhGWVSr;
  HvTable hTable_5PNildp5;
  ControlBinop cBinop_mNb9Ca16;
  ControlVar cVar_jvJOZKyY;
  ControlBinop cBinop_ngSH3RSW;
  ControlBinop cBinop_faOQpRZ4;
  SignalVarf sVarf_R89a959p;
  SignalVarf sVarf_ANp2JNvR;
  SignalVarf sVarf_dscb5kI6;
  ControlVar cVar_DEQEjUaB;
  ControlBinop cBinop_RnVREVOr;
  ControlBinop cBinop_M1rYzLn2;
  SignalVarf sVarf_CBm7JdWF;
  SignalVarf sVarf_NKvnNPuT;
  SignalVarf sVarf_KEAa3I2E;
  ControlBinop cBinop_hGhpI6Tr;
  ControlBinop cBinop_yulHe7j1;
  ControlBinop cBinop_bxkg0BuH;
  ControlBinop cBinop_DzBN6v4F;
  ControlBinop cBinop_glJRVYDE;
  ControlBinop cBinop_v8G3wTYK;
  ControlBinop cBinop_5su4ELor;
  ControlBinop cBinop_jvhb1jic;
  ControlBinop cBinop_isGtmPjr;
  SignalVarf sVarf_gnFROSqg;
  ControlVar cVar_lSjhJZX2;
  ControlBinop cBinop_IxBcsGYb;
  ControlBinop cBinop_8cSaXQvC;
  ControlBinop cBinop_DWFq7eR1;
  ControlBinop cBinop_yyITAWYk;
  ControlBinop cBinop_w53GIKJd;
  ControlBinop cBinop_j2P4WAWH;
  ControlBinop cBinop_gz99z59u;
  SignalVarf sVarf_MkT9IYOz;
  ControlBinop cBinop_zs5MYwzG;
  ControlRandom cRandom_hsSGXTKj;
  ControlSlice cSlice_InBuZaVu;
  ControlDelay cDelay_D13TjngW;
  ControlVar cVar_NYgwUA9N;
  ControlBinop cBinop_Wj1TQHDy;
  ControlBinop cBinop_9CCk6Sfc;
  ControlBinop cBinop_aR8oMNMC;
  ControlTabhead cTabhead_KUtG2gVr;
  ControlVar cVar_FM1utm2R;
  ControlDelay cDelay_ofTVmWd8;
  ControlDelay cDelay_ZPpFgXKp;
  ControlBinop cBinop_Vs4tNmww;
  ControlBinop cBinop_exoHZufZ;
  ControlBinop cBinop_7ApNNQMu;
  ControlBinop cBinop_lcDHjdX3;
  ControlBinop cBinop_vZu3hYay;
  ControlBinop cBinop_CG7pfxN8;
  ControlTabhead cTabhead_gjCYvMPN;
  ControlVar cVar_7JsNZ5tk;
  ControlDelay cDelay_oja5cqE7;
  ControlDelay cDelay_y9WDKF9d;
  ControlBinop cBinop_z5dCco2X;
  ControlBinop cBinop_IbxZ8bDL;
  ControlBinop cBinop_urmdW32S;
  ControlBinop cBinop_S1UmaDov;
  ControlBinop cBinop_rz37IN2V;
  ControlBinop cBinop_bh23WgNV;
  ControlTabhead cTabhead_5OxP1yx2;
  ControlVar cVar_v04riKtU;
  ControlDelay cDelay_FBWcFVzU;
  ControlDelay cDelay_LOL15Bwx;
  ControlBinop cBinop_uye8cHGP;
  ControlBinop cBinop_U0nNxuGd;
  ControlBinop cBinop_IVgJgAah;
  ControlBinop cBinop_P2PnV67D;
  ControlBinop cBinop_gp1lA5TZ;
  ControlBinop cBinop_4sFF5IF0;
  ControlTabhead cTabhead_2YpONAO6;
  ControlVar cVar_0jjqNT8r;
  ControlDelay cDelay_jBgQgC7J;
  ControlDelay cDelay_M15XfGBG;
  ControlBinop cBinop_ohrPUjUQ;
  ControlBinop cBinop_dr7FrhVd;
  ControlBinop cBinop_UJ8WubBN;
  ControlBinop cBinop_gOuceqPu;
  ControlBinop cBinop_IvcHvN1T;
  ControlBinop cBinop_bVT6SqqL;
  ControlDelay cDelay_oklNCsq2;
  ControlDelay cDelay_pIOQSB4M;
  ControlBinop cBinop_nhARv1Zn;
  HvTable hTable_oNMFCw27;
  ControlBinop cBinop_rpVIUfZq;
  ControlDelay cDelay_GeJzDG5D;
  ControlDelay cDelay_bztv2R9U;
  ControlBinop cBinop_AgT5wfJr;
  HvTable hTable_XWWQ7oGZ;
  ControlBinop cBinop_7MXEJbDz;
  ControlDelay cDelay_Q96iqBnK;
  ControlDelay cDelay_5BnR4jW9;
  ControlBinop cBinop_NSuphcQS;
  HvTable hTable_a8GQeZi7;
  ControlBinop cBinop_AGi8B3zm;
  ControlDelay cDelay_J71nXzoi;
  ControlDelay cDelay_VZmevt2Q;
  ControlBinop cBinop_id5wskjk;
  HvTable hTable_It44TaoQ;
  ControlBinop cBinop_u9FrnO4U;
  ControlPack cPack_F7rUmkZo;
  ControlPack cPack_sGtGAT5V;
  ControlBinop cBinop_kfHJG2Fb;
  ControlBinop cBinop_6GHiMtMt;
  ControlVar cVar_97QunPUQ;
  ControlBinop cBinop_6cUwqBnX;
  ControlBinop cBinop_o099PLNB;
  SignalVarf sVarf_LNHrOYYa;
  ControlBinop cBinop_on3TyeH1;
  ControlBinop cBinop_Rm3EdkBR;
  ControlBinop cBinop_AmVVwcC7;
  SignalVarf sVarf_N2JXSvEI;
  ControlVar cVar_DX20MxIJ;
  ControlVar cVar_irzKSqgx;
  ControlVar cVar_euDv1hrK;
  ControlVar cVar_cAYmo345;
  ControlIf cIf_SEFcjWG3;
  ControlBinop cBinop_y1JvNlyk;
  ControlBinop cBinop_db0Yzvsr;
  ControlBinop cBinop_V9Gqw3pJ;
  ControlDelay cDelay_krBgENcG;
  ControlDelay cDelay_kdszcoJJ;
  ControlBinop cBinop_OVr7l9oA;
  HvTable hTable_GsOiTsvz;
  ControlBinop cBinop_9Kx510FL;
  ControlTabhead cTabhead_vTB1GvGl;
  ControlVar cVar_vVy3wVAq;
  ControlDelay cDelay_xQBRn5in;
  ControlDelay cDelay_w5qZvUOz;
  ControlBinop cBinop_9Vaejsez;
  ControlBinop cBinop_LdiZ4E2e;
  ControlBinop cBinop_7aZpItSO;
  ControlBinop cBinop_MeDhfnTv;
  ControlBinop cBinop_AD06blM7;
  ControlBinop cBinop_eVDTi0Oy;
  ControlDelay cDelay_LzDoLlnR;
  ControlDelay cDelay_E1FhQp3i;
  ControlBinop cBinop_8yp5mgRT;
  HvTable hTable_LgT9iNqQ;
  ControlBinop cBinop_V4WcTCrv;
  ControlTabhead cTabhead_q10hbw3a;
  ControlVar cVar_La2uLvsX;
  ControlDelay cDelay_ct1dScD8;
  ControlDelay cDelay_jMxFHuA2;
  ControlBinop cBinop_BCS7E3xj;
  ControlBinop cBinop_adJoWq4D;
  ControlBinop cBinop_pUg5ZQcx;
  ControlBinop cBinop_RHuFHAHI;
  ControlBinop cBinop_5EzqO2SM;
  ControlBinop cBinop_zjHWK5Xq;
  ControlDelay cDelay_C9kd8RNI;
  ControlDelay cDelay_UUF0djwA;
  ControlBinop cBinop_9uJWxJbt;
  HvTable hTable_um2wrYRw;
  ControlBinop cBinop_bRF8Ehc7;
  ControlTabhead cTabhead_DOCSSkCW;
  ControlVar cVar_y8QvfIRM;
  ControlDelay cDelay_r36RCa9d;
  ControlDelay cDelay_rR5NMt5w;
  ControlBinop cBinop_pZNctJiL;
  ControlBinop cBinop_2YTnB5Jh;
  ControlBinop cBinop_wywqE2ZD;
  ControlBinop cBinop_ZNkJsEZ3;
  ControlBinop cBinop_KNQZ5SiV;
  ControlBinop cBinop_pbcN7Zyk;
  ControlDelay cDelay_5Kaw9835;
  ControlDelay cDelay_SwNNDQLW;
  ControlBinop cBinop_9PLWmVqe;
  HvTable hTable_o4jZZY1g;
  ControlBinop cBinop_QMeDDV2t;
  ControlTabhead cTabhead_Xsz7uXJG;
  ControlVar cVar_TnoMnGNh;
  ControlDelay cDelay_m6MlFbcL;
  ControlDelay cDelay_Z9eL5IlI;
  ControlBinop cBinop_R2ptISsU;
  ControlBinop cBinop_YAO6dyUf;
  ControlBinop cBinop_NKgygMKl;
  ControlBinop cBinop_JjQPOEEq;
  ControlBinop cBinop_taqbBcHR;
  ControlBinop cBinop_lwuDu1vN;
  ControlDelay cDelay_3iokE1wj;
  ControlDelay cDelay_n5JwE6Ok;
  ControlBinop cBinop_U3kIWgHj;
  HvTable hTable_EReTiHZ1;
  ControlBinop cBinop_Kb6uA85l;
  ControlTabhead cTabhead_owRzuOw0;
  ControlVar cVar_ZHvubGhI;
  ControlDelay cDelay_SnsW5H9v;
  ControlDelay cDelay_hLdIvfws;
  ControlBinop cBinop_LYeXtCSZ;
  ControlBinop cBinop_ZsrADDtB;
  ControlBinop cBinop_KcNFhBYm;
  ControlBinop cBinop_aD2AimRs;
  ControlBinop cBinop_6QWuWGDz;
  ControlBinop cBinop_eLxGKmcV;
  ControlDelay cDelay_CiaqsZkU;
  ControlDelay cDelay_g6RmIu5F;
  ControlBinop cBinop_2gVCepuW;
  HvTable hTable_548ftrN1;
  ControlBinop cBinop_zyzVqeCX;
  ControlTabhead cTabhead_wTppF3lG;
  ControlVar cVar_zQ2cLko9;
  ControlDelay cDelay_sYXkKMwG;
  ControlDelay cDelay_h0pbf47T;
  ControlBinop cBinop_hA6hjOx8;
  ControlBinop cBinop_wRKdrJso;
  ControlBinop cBinop_Wm4O0sL0;
  ControlBinop cBinop_PIH8zAQf;
  ControlBinop cBinop_SqGIEkLv;
  ControlBinop cBinop_Ia3OQ22P;
  ControlVar cVar_foaqfjHh;
  ControlVar cVar_Cfy6Ph7Y;
  ControlPack cPack_t38m1xB2;
  ControlVar cVar_LRvFyzdq;
  ControlBinop cBinop_DoNxcx1a;
  ControlBinop cBinop_N3WAPR2i;
  SignalVarf sVarf_YHzmwJRR;
  ControlBinop cBinop_T9uD0XfH;
  ControlBinop cBinop_KuwH7BgA;
  ControlBinop cBinop_nFAoXcHN;
  SignalVarf sVarf_m4Sqb3Fg;
  ControlVar cVar_oA9LNXyk;
  ControlBinop cBinop_3cCjnbrL;
  ControlBinop cBinop_ufAc4CBo;
  SignalVarf sVarf_Qy1RPXpi;
  ControlBinop cBinop_Jk1c28G6;
  ControlBinop cBinop_HogPvksm;
  ControlBinop cBinop_9Dx7YwDn;
  SignalVarf sVarf_T4Z1e7Pw;
  ControlVar cVar_lLfICOrO;
  ControlBinop cBinop_7nCWqV70;
  ControlBinop cBinop_KnrTls2v;
  SignalVarf sVarf_Eo9i292A;
  ControlBinop cBinop_DGM0sPHw;
  ControlBinop cBinop_hcIoNgSy;
  ControlBinop cBinop_96v8FBqG;
  SignalVarf sVarf_xoziU3W5;
  ControlBinop cBinop_EjZTNPEn;
  ControlBinop cBinop_xhZ7Yu8W;
  ControlBinop cBinop_mi3gSZdJ;
  ControlDelay cDelay_1D5gvrUH;
  ControlVar cVar_aa8uhMDb;
  ControlBinop cBinop_EzZ8HkiG;
  ControlBinop cBinop_7fgd1N8O;
  ControlBinop cBinop_sJfkHgvc;
  ControlVar cVar_AMVmFkpT;
  ControlVar cVar_4VnwJYoe;
  ControlIf cIf_Fv0GE5Ln;
  ControlBinop cBinop_ZMEl0VjE;
  ControlDelay cDelay_DVS5u9cE;
  ControlDelay cDelay_xS5fJ2jF;
  ControlBinop cBinop_SWC0eQZT;
  HvTable hTable_hb1HOJja;
  ControlBinop cBinop_caWcDoSR;
  ControlTabhead cTabhead_vd7LwTv4;
  ControlVar cVar_PPZCHPaJ;
  ControlDelay cDelay_3LHNw9qv;
  ControlDelay cDelay_DKbBTw0s;
  ControlBinop cBinop_a4fXsdX6;
  ControlBinop cBinop_kPO9Qomq;
  ControlBinop cBinop_fsrtILvs;
  ControlBinop cBinop_JFPihXUj;
  ControlBinop cBinop_DKqyMYbL;
  ControlBinop cBinop_W0HMG76r;
  ControlVar cVar_nRVBSSSP;
  ControlVar cVar_qZG9sv45;
  ControlVar cVar_RAlphUC6;
  ControlVar cVar_uc9nvINl;
  ControlVar cVar_MLXTCCNe;
  ControlVar cVar_Mkw3vVGY;
  ControlIf cIf_TQBz5o43;
  ControlBinop cBinop_NxCehDgY;
  ControlVar cVar_yzhbuYPc;
  ControlIf cIf_IbyA0xbd;
  ControlBinop cBinop_hbb79JyR;
  ControlSlice cSlice_yLCWoWTA;
  ControlSlice cSlice_lrucTbd6;
  ControlVar cVar_V4PjMotn;
  ControlIf cIf_tSIvkysO;
  ControlBinop cBinop_3sK9qNLL;
  ControlIf cIf_zVNMz1Kh;
  ControlIf cIf_AZEwPb2f;
  ControlIf cIf_TmBM4xcT;
  ControlIf cIf_JH1UhyZK;
  ControlIf cIf_LsaiPGyZ;
  SignalVarf sVarf_qRDt9ji2;
  ControlBinop cBinop_THERKaV0;
  ControlBinop cBinop_qZx4uLHH;
  ControlBinop cBinop_ctL4CrjG;
  ControlBinop cBinop_Ypvm3vqO;
  SignalVarf sVarf_6ZTrghAQ;
  ControlBinop cBinop_lo6mqpJN;
  ControlBinop cBinop_IfEbSbqg;
  SignalVarf sVarf_vpo016UC;
  SignalVarf sVarf_M7NhQ6RK;
  ControlBinop cBinop_PH5Zkxzd;
  ControlBinop cBinop_g5CLYQOs;
  ControlBinop cBinop_SfEP95Wl;
  ControlBinop cBinop_X4pitM90;
  ControlBinop cBinop_LQJ69bOY;
  ControlBinop cBinop_50rgpKrk;
  ControlBinop cBinop_MYVfFUYt;
  ControlBinop cBinop_OSpDxYWs;
  ControlBinop cBinop_gRScYxnE;
  ControlBinop cBinop_jvRWF5HR;
  ControlBinop cBinop_se8z84Pb;
  ControlBinop cBinop_Xvlt9p8p;
  ControlBinop cBinop_z7K4L2xC;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
