/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_7HVtj4CL, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_HVPAUopZ);
  numBytes += sLine_init(&sLine_h8v9UHnn);
  numBytes += sTabhead_init(&sTabhead_ftU7Uwc5, &hTable_5PNildp5);
  numBytes += sTabread_init(&sTabread_JsBf97q1, &hTable_5PNildp5, false);
  numBytes += sTabread_init(&sTabread_UR9PZRT4, &hTable_5PNildp5, false);
  numBytes += sTabhead_init(&sTabhead_KEGHBg61, &hTable_5PNildp5);
  numBytes += sTabread_init(&sTabread_CvNN9v6O, &hTable_5PNildp5, false);
  numBytes += sTabread_init(&sTabread_Lb5hipas, &hTable_5PNildp5, false);
  numBytes += sTabwrite_init(&sTabwrite_PwcRmY1B, &hTable_5PNildp5);
  numBytes += sRPole_init(&sRPole_Z8H8AxIY);
  numBytes += sDel1_init(&sDel1_pKOIkqKp);
  numBytes += sTabread_init(&sTabread_OJBXKnEe, &hTable_hb1HOJja, true);
  numBytes += sTabwrite_init(&sTabwrite_R7yICHDe, &hTable_hb1HOJja);
  numBytes += sTabread_init(&sTabread_rfKaknlM, &hTable_oNMFCw27, true);
  numBytes += sRPole_init(&sRPole_vxZVhBLt);
  numBytes += sLine_init(&sLine_oTevwxgp);
  numBytes += sLine_init(&sLine_m1gS2Xca);
  numBytes += sTabread_init(&sTabread_SUZKXQRN, &hTable_GsOiTsvz, true);
  numBytes += sTabread_init(&sTabread_uZ6SVxqP, &hTable_LgT9iNqQ, true);
  numBytes += sTabread_init(&sTabread_Mn2G4XeJ, &hTable_um2wrYRw, true);
  numBytes += sTabread_init(&sTabread_pJhzhhBS, &hTable_o4jZZY1g, true);
  numBytes += sTabread_init(&sTabread_swWfKNoP, &hTable_548ftrN1, true);
  numBytes += sTabread_init(&sTabread_m8BHiEq3, &hTable_EReTiHZ1, true);
  numBytes += sTabwrite_init(&sTabwrite_NZZRa13l, &hTable_GsOiTsvz);
  numBytes += sTabwrite_init(&sTabwrite_AsxBkHKU, &hTable_LgT9iNqQ);
  numBytes += sTabwrite_init(&sTabwrite_8bB1UpFy, &hTable_um2wrYRw);
  numBytes += sTabwrite_init(&sTabwrite_EOxuAuIY, &hTable_o4jZZY1g);
  numBytes += sTabwrite_init(&sTabwrite_KzcEh0cu, &hTable_EReTiHZ1);
  numBytes += sTabwrite_init(&sTabwrite_JxQ4H07J, &hTable_548ftrN1);
  numBytes += sTabread_init(&sTabread_WAVAKt7r, &hTable_XWWQ7oGZ, true);
  numBytes += sRPole_init(&sRPole_aJ7GvkAJ);
  numBytes += sTabread_init(&sTabread_JnCW7j4M, &hTable_a8GQeZi7, true);
  numBytes += sRPole_init(&sRPole_DV4TeETt);
  numBytes += sTabread_init(&sTabread_ftzb4YEe, &hTable_It44TaoQ, true);
  numBytes += sRPole_init(&sRPole_uOavXcxN);
  numBytes += sTabwrite_init(&sTabwrite_9tYqz89q, &hTable_oNMFCw27);
  numBytes += sTabwrite_init(&sTabwrite_vtASE6W0, &hTable_XWWQ7oGZ);
  numBytes += sTabwrite_init(&sTabwrite_Y16JGJ4M, &hTable_a8GQeZi7);
  numBytes += sTabwrite_init(&sTabwrite_1dxgHgP1, &hTable_It44TaoQ);
  numBytes += sLine_init(&sLine_azXGJ5Db);
  numBytes += cVar_init_f(&cVar_oFcUla5F, 0.0f);
  numBytes += cVar_init_f(&cVar_LlAA3JdI, 0.0f);
  numBytes += cPack_init(&cPack_RyaEcH5w, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_GGwcz9hI, 0.0f);
  numBytes += cPack_init(&cPack_d03YQtdA, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_cUkoo3aw, 0.0f);
  numBytes += cVar_init_f(&cVar_EhpcMKyv, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Yff6HiTU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_V7BAbTyf, 0.0f);
  numBytes += hTable_init(&hTable_5PNildp5, 256);
  numBytes += cVar_init_s(&cVar_jvJOZKyY, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_R89a959p, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ANp2JNvR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dscb5kI6, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_DEQEjUaB, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_CBm7JdWF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NKvnNPuT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KEAa3I2E, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_hGhpI6Tr, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_gnFROSqg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lSjhJZX2, 0.0f);
  numBytes += cBinop_init(&cBinop_gz99z59u, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_MkT9IYOz, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_hsSGXTKj, -1405504690);
  numBytes += cSlice_init(&cSlice_InBuZaVu, 1, 1);
  numBytes += cDelay_init(this, &cDelay_D13TjngW, 0.0f);
  numBytes += cVar_init_f(&cVar_NYgwUA9N, 5.0f);
  numBytes += cBinop_init(&cBinop_aR8oMNMC, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_KUtG2gVr, &hTable_oNMFCw27);
  numBytes += cVar_init_s(&cVar_FM1utm2R, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_ofTVmWd8, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_ZPpFgXKp, 0.0f);
  numBytes += cBinop_init(&cBinop_Vs4tNmww, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_7ApNNQMu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_lcDHjdX3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_CG7pfxN8, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_gjCYvMPN, &hTable_XWWQ7oGZ);
  numBytes += cVar_init_s(&cVar_7JsNZ5tk, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_oja5cqE7, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_y9WDKF9d, 0.0f);
  numBytes += cBinop_init(&cBinop_z5dCco2X, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_urmdW32S, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_S1UmaDov, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_bh23WgNV, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_5OxP1yx2, &hTable_a8GQeZi7);
  numBytes += cVar_init_s(&cVar_v04riKtU, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_FBWcFVzU, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_LOL15Bwx, 0.0f);
  numBytes += cBinop_init(&cBinop_uye8cHGP, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_IVgJgAah, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_P2PnV67D, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_4sFF5IF0, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_2YpONAO6, &hTable_It44TaoQ);
  numBytes += cVar_init_s(&cVar_0jjqNT8r, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_jBgQgC7J, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_M15XfGBG, 0.0f);
  numBytes += cBinop_init(&cBinop_ohrPUjUQ, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_UJ8WubBN, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_gOuceqPu, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_bVT6SqqL, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_oklNCsq2, 0.0f);
  numBytes += cDelay_init(this, &cDelay_pIOQSB4M, 0.0f);
  numBytes += hTable_init(&hTable_oNMFCw27, 256);
  numBytes += cDelay_init(this, &cDelay_GeJzDG5D, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bztv2R9U, 0.0f);
  numBytes += hTable_init(&hTable_XWWQ7oGZ, 256);
  numBytes += cDelay_init(this, &cDelay_Q96iqBnK, 0.0f);
  numBytes += cDelay_init(this, &cDelay_5BnR4jW9, 0.0f);
  numBytes += hTable_init(&hTable_a8GQeZi7, 256);
  numBytes += cDelay_init(this, &cDelay_J71nXzoi, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VZmevt2Q, 0.0f);
  numBytes += hTable_init(&hTable_It44TaoQ, 256);
  numBytes += cPack_init(&cPack_F7rUmkZo, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_sGtGAT5V, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_97QunPUQ, 22050.0f);
  numBytes += cBinop_init(&cBinop_6cUwqBnX, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_LNHrOYYa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_N2JXSvEI, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DX20MxIJ, 0.0f);
  numBytes += cVar_init_f(&cVar_irzKSqgx, 0.0f);
  numBytes += cVar_init_f(&cVar_euDv1hrK, 0.0f);
  numBytes += cVar_init_f(&cVar_cAYmo345, 0.0f);
  numBytes += cIf_init(&cIf_SEFcjWG3, false);
  numBytes += cDelay_init(this, &cDelay_krBgENcG, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kdszcoJJ, 0.0f);
  numBytes += hTable_init(&hTable_GsOiTsvz, 256);
  numBytes += cTabhead_init(&cTabhead_vTB1GvGl, &hTable_GsOiTsvz);
  numBytes += cVar_init_s(&cVar_vVy3wVAq, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_xQBRn5in, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_w5qZvUOz, 0.0f);
  numBytes += cBinop_init(&cBinop_9Vaejsez, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_7aZpItSO, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_MeDhfnTv, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_eVDTi0Oy, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_LzDoLlnR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_E1FhQp3i, 0.0f);
  numBytes += hTable_init(&hTable_LgT9iNqQ, 256);
  numBytes += cTabhead_init(&cTabhead_q10hbw3a, &hTable_LgT9iNqQ);
  numBytes += cVar_init_s(&cVar_La2uLvsX, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_ct1dScD8, 25.796f);
  numBytes += cDelay_init(this, &cDelay_jMxFHuA2, 0.0f);
  numBytes += cBinop_init(&cBinop_BCS7E3xj, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_pUg5ZQcx, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_RHuFHAHI, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_zjHWK5Xq, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_C9kd8RNI, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UUF0djwA, 0.0f);
  numBytes += hTable_init(&hTable_um2wrYRw, 256);
  numBytes += cTabhead_init(&cTabhead_DOCSSkCW, &hTable_um2wrYRw);
  numBytes += cVar_init_s(&cVar_y8QvfIRM, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_r36RCa9d, 19.392f);
  numBytes += cDelay_init(this, &cDelay_rR5NMt5w, 0.0f);
  numBytes += cBinop_init(&cBinop_pZNctJiL, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_wywqE2ZD, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ZNkJsEZ3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_pbcN7Zyk, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_5Kaw9835, 0.0f);
  numBytes += cDelay_init(this, &cDelay_SwNNDQLW, 0.0f);
  numBytes += hTable_init(&hTable_o4jZZY1g, 256);
  numBytes += cTabhead_init(&cTabhead_Xsz7uXJG, &hTable_o4jZZY1g);
  numBytes += cVar_init_s(&cVar_TnoMnGNh, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_m6MlFbcL, 16.364f);
  numBytes += cDelay_init(this, &cDelay_Z9eL5IlI, 0.0f);
  numBytes += cBinop_init(&cBinop_R2ptISsU, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_NKgygMKl, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_JjQPOEEq, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_lwuDu1vN, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_3iokE1wj, 0.0f);
  numBytes += cDelay_init(this, &cDelay_n5JwE6Ok, 0.0f);
  numBytes += hTable_init(&hTable_EReTiHZ1, 256);
  numBytes += cTabhead_init(&cTabhead_owRzuOw0, &hTable_EReTiHZ1);
  numBytes += cVar_init_s(&cVar_ZHvubGhI, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_SnsW5H9v, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_hLdIvfws, 0.0f);
  numBytes += cBinop_init(&cBinop_LYeXtCSZ, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_KcNFhBYm, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_aD2AimRs, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_eLxGKmcV, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_CiaqsZkU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_g6RmIu5F, 0.0f);
  numBytes += hTable_init(&hTable_548ftrN1, 256);
  numBytes += cTabhead_init(&cTabhead_wTppF3lG, &hTable_548ftrN1);
  numBytes += cVar_init_s(&cVar_zQ2cLko9, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_sYXkKMwG, 7.645f);
  numBytes += cDelay_init(this, &cDelay_h0pbf47T, 0.0f);
  numBytes += cBinop_init(&cBinop_hA6hjOx8, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_Wm4O0sL0, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_PIH8zAQf, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Ia3OQ22P, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_foaqfjHh, 0.0f);
  numBytes += cVar_init_f(&cVar_Cfy6Ph7Y, 0.0f);
  numBytes += cPack_init(&cPack_t38m1xB2, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_LRvFyzdq, 22050.0f);
  numBytes += cBinop_init(&cBinop_DoNxcx1a, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_YHzmwJRR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m4Sqb3Fg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oA9LNXyk, 22050.0f);
  numBytes += cBinop_init(&cBinop_3cCjnbrL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Qy1RPXpi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T4Z1e7Pw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lLfICOrO, 22050.0f);
  numBytes += cBinop_init(&cBinop_7nCWqV70, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Eo9i292A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xoziU3W5, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_1D5gvrUH, 0.0f);
  numBytes += cVar_init_f(&cVar_aa8uhMDb, 1000.0f);
  numBytes += cBinop_init(&cBinop_sJfkHgvc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_AMVmFkpT, 0.0f);
  numBytes += cVar_init_f(&cVar_4VnwJYoe, 0.0f);
  numBytes += cIf_init(&cIf_Fv0GE5Ln, false);
  numBytes += cDelay_init(this, &cDelay_DVS5u9cE, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xS5fJ2jF, 0.0f);
  numBytes += hTable_init(&hTable_hb1HOJja, 256);
  numBytes += cTabhead_init(&cTabhead_vd7LwTv4, &hTable_hb1HOJja);
  numBytes += cVar_init_s(&cVar_PPZCHPaJ, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_3LHNw9qv, 150.0f);
  numBytes += cDelay_init(this, &cDelay_DKbBTw0s, 0.0f);
  numBytes += cBinop_init(&cBinop_a4fXsdX6, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_fsrtILvs, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_JFPihXUj, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_W0HMG76r, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_nRVBSSSP, 0.0f);
  numBytes += cVar_init_f(&cVar_qZG9sv45, 0.0f);
  numBytes += cVar_init_f(&cVar_RAlphUC6, 0.0f);
  numBytes += cVar_init_f(&cVar_uc9nvINl, 0.0f);
  numBytes += cVar_init_f(&cVar_MLXTCCNe, 0.0f);
  numBytes += cVar_init_f(&cVar_Mkw3vVGY, 0.0f);
  numBytes += cIf_init(&cIf_TQBz5o43, false);
  numBytes += cVar_init_f(&cVar_yzhbuYPc, 0.0f);
  numBytes += cIf_init(&cIf_IbyA0xbd, false);
  numBytes += cSlice_init(&cSlice_yLCWoWTA, 1, -1);
  numBytes += cSlice_init(&cSlice_lrucTbd6, 1, -1);
  numBytes += cVar_init_f(&cVar_V4PjMotn, 0.0f);
  numBytes += cIf_init(&cIf_tSIvkysO, false);
  numBytes += cBinop_init(&cBinop_3sK9qNLL, 0.0f); // __neq
  numBytes += cIf_init(&cIf_zVNMz1Kh, false);
  numBytes += cIf_init(&cIf_AZEwPb2f, false);
  numBytes += cIf_init(&cIf_TmBM4xcT, false);
  numBytes += cIf_init(&cIf_JH1UhyZK, true);
  numBytes += cIf_init(&cIf_LsaiPGyZ, false);
  numBytes += sVarf_init(&sVarf_qRDt9ji2, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_ctL4CrjG, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_6ZTrghAQ, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_lo6mqpJN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_IfEbSbqg, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_vpo016UC, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M7NhQ6RK, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_g5CLYQOs, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_gRScYxnE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_jvRWF5HR, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_se8z84Pb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Xvlt9p8p, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_z7K4L2xC, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_RyaEcH5w);
  cPack_free(&cPack_d03YQtdA);
  hTable_free(&hTable_5PNildp5);
  hTable_free(&hTable_oNMFCw27);
  hTable_free(&hTable_XWWQ7oGZ);
  hTable_free(&hTable_a8GQeZi7);
  hTable_free(&hTable_It44TaoQ);
  cPack_free(&cPack_F7rUmkZo);
  cPack_free(&cPack_sGtGAT5V);
  hTable_free(&hTable_GsOiTsvz);
  hTable_free(&hTable_LgT9iNqQ);
  hTable_free(&hTable_um2wrYRw);
  hTable_free(&hTable_o4jZZY1g);
  hTable_free(&hTable_EReTiHZ1);
  hTable_free(&hTable_548ftrN1);
  cPack_free(&cPack_t38m1xB2);
  hTable_free(&hTable_hb1HOJja);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_5PNildp5; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_oNMFCw27; // del-1052-del1
    case 0xA2AC524D: return &hTable_XWWQ7oGZ; // del-1052-del2
    case 0xE36A35B: return &hTable_a8GQeZi7; // del-1052-del3
    case 0x48CE0509: return &hTable_It44TaoQ; // del-1052-del4
    case 0xE34D6E72: return &hTable_GsOiTsvz; // del-1052-ref1
    case 0x6A1027AB: return &hTable_LgT9iNqQ; // del-1052-ref2
    case 0xA37C6D49: return &hTable_um2wrYRw; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_o4jZZY1g; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_EReTiHZ1; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_548ftrN1; // del-1052-ref5
    case 0xED65564F: return &hTable_hb1HOJja; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DnSMCQa8_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S0v48UNk_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DVMAavCq_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xscYC6H7_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G1Ndn83f_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cOGbNAD3_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JcH5wWHv_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_azvQhyOH_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pkNWiGW3_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_thjm6SAD_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_977bYG3Q_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Nd4IY5Nu_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GzmhsDvQ_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0YA6dVWy_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pZFu88rQ_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cRd0ECzu_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Na18ZR6H_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eacOeBD4_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TaQxwRN7_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aDsVRz9E_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PhilGpqx_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k8AIPn6H_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WcE6IlTt_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1O1F6qTF_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_oFcUla5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_DzBN6v4F_sendMessage);
}

void Heavy_ChaffVerb::cVar_LlAA3JdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5su4ELor_sendMessage);
}

void Heavy_ChaffVerb::cPack_RyaEcH5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_HVPAUopZ, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_dwyDRD7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GGwcz9hI, 0, m, &cVar_GGwcz9hI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gMEjjhnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_dwyDRD7V_sendMessage);
}

void Heavy_ChaffVerb::cVar_GGwcz9hI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bxkg0BuH_sendMessage);
}

void Heavy_ChaffVerb::cPack_d03YQtdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_h8v9UHnn, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_cUkoo3aw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_v8G3wTYK_sendMessage);
}

void Heavy_ChaffVerb::cVar_EhpcMKyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_7HVtj4CL, 0, m);
}

void Heavy_ChaffVerb::cMsg_Ml9wlwsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tjI0lPtQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tjI0lPtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mNb9Ca16_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Yff6HiTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Yff6HiTU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_V7BAbTyf, 0, m, &cDelay_V7BAbTyf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Yff6HiTU, 0, m, &cDelay_Yff6HiTU_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PwcRmY1B, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_V7BAbTyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V7BAbTyf, m);
  cMsg_ZKt1K8jI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_eoQHsb6N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_EMI6E57Z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_UGhGWVSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7fX3MJLe_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_5PNildp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eQitHZk5_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Yff6HiTU, 2, m, &cDelay_Yff6HiTU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AzAYHMFy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7fX3MJLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5PNildp5, 0, m, &hTable_5PNildp5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mNb9Ca16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_UGhGWVSr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZKt1K8jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5PNildp5, 0, m, &hTable_5PNildp5_sendMessage);
}

void Heavy_ChaffVerb::cCast_AzAYHMFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Yff6HiTU, 0, m, &cDelay_Yff6HiTU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eQitHZk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_V7BAbTyf, 2, m, &cDelay_V7BAbTyf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EMI6E57Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PwcRmY1B, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_QWAad5vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_liDFnr6S_sendMessage);
}

void Heavy_ChaffVerb::cSystem_liDFnr6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ngSH3RSW_sendMessage);
}

void Heavy_ChaffVerb::cVar_jvJOZKyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eXyPMiNc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_vjFIRdir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_faOQpRZ4_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_R89a959p, m);
}

void Heavy_ChaffVerb::cBinop_ngSH3RSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ANp2JNvR, m);
}

void Heavy_ChaffVerb::cMsg_eXyPMiNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vjFIRdir_sendMessage);
}

void Heavy_ChaffVerb::cBinop_faOQpRZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dscb5kI6, m);
}

void Heavy_ChaffVerb::cMsg_MOXoG7ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ADsGgHrd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ADsGgHrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RnVREVOr_sendMessage);
}

void Heavy_ChaffVerb::cVar_DEQEjUaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T50daCct_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_in4MfCTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_M1rYzLn2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CBm7JdWF, m);
}

void Heavy_ChaffVerb::cBinop_RnVREVOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NKvnNPuT, m);
}

void Heavy_ChaffVerb::cMsg_T50daCct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_in4MfCTj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M1rYzLn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KEAa3I2E, m);
}

void Heavy_ChaffVerb::cBinop_hGhpI6Tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EhpcMKyv, 0, m, &cVar_EhpcMKyv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yulHe7j1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DBdm3h8H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IIT4RGcg_sendMessage);
}

void Heavy_ChaffVerb::cCast_IIT4RGcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hGhpI6Tr, HV_BINOP_DIVIDE, 0, m, &cBinop_hGhpI6Tr_sendMessage);
}

void Heavy_ChaffVerb::cCast_DBdm3h8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hGhpI6Tr, HV_BINOP_DIVIDE, 1, m, &cBinop_hGhpI6Tr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bxkg0BuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_glJRVYDE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DzBN6v4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_gMEjjhnb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_glJRVYDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hGhpI6Tr, HV_BINOP_DIVIDE, 0, m, &cBinop_hGhpI6Tr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_v8G3wTYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_d03YQtdA, 0, m, &cPack_d03YQtdA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5su4ELor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_yulHe7j1_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_RyaEcH5w, 0, m, &cPack_RyaEcH5w_sendMessage);
}

void Heavy_ChaffVerb::cUnop_H2zCWmrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZEwPb2f, 0, m, &cIf_AZEwPb2f_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_KvUSitgh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ttId421T_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bvbpFePm_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EQ16q4I1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_ttId421T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GXwbNZiH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_bvbpFePm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3vput0P1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_EQ16q4I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YIrWeIx3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_jvhb1jic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_isGtmPjr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_isGtmPjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IxBcsGYb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yyITAWYk_sendMessage);
}

void Heavy_ChaffVerb::cVar_lSjhJZX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_w53GIKJd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZcrcqhSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E5KZAY6u_sendMessage);
}

void Heavy_ChaffVerb::cSystem_E5KZAY6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gz99z59u, HV_BINOP_DIVIDE, 1, m, &cBinop_gz99z59u_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IxBcsGYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8cSaXQvC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8cSaXQvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MkT9IYOz, m);
}

void Heavy_ChaffVerb::cMsg_CcTg1iOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DWFq7eR1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DWFq7eR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jvhb1jic_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yyITAWYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gnFROSqg, m);
}

void Heavy_ChaffVerb::cBinop_w53GIKJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_j2P4WAWH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j2P4WAWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gz99z59u, HV_BINOP_DIVIDE, 0, m, &cBinop_gz99z59u_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gz99z59u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CcTg1iOf_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_hAj0ddyj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_InBuZaVu, 0, m, &cSlice_InBuZaVu_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_hsSGXTKj, 0, m, &cRandom_hsSGXTKj_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_zs5MYwzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_XDHsTwhb_sendMessage);
}

void Heavy_ChaffVerb::cUnop_XDHsTwhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_qZx4uLHH_sendMessage);
}

void Heavy_ChaffVerb::cRandom_hsSGXTKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_zs5MYwzG_sendMessage);
}

void Heavy_ChaffVerb::cSlice_InBuZaVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_hsSGXTKj, 1, m, &cRandom_hsSGXTKj_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_Ml155X1x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_uKk4rjgG_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_uKk4rjgG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_skSgcmfD_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_D13TjngW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D13TjngW, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D13TjngW, 0, m, &cDelay_D13TjngW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AMVmFkpT, 0, m, &cVar_AMVmFkpT_sendMessage);
}

void Heavy_ChaffVerb::cCast_skSgcmfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uKk4rjgG_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D13TjngW, 0, m, &cDelay_D13TjngW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AMVmFkpT, 0, m, &cVar_AMVmFkpT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Opzsexs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hYPemNXj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hYPemNXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9CCk6Sfc_sendMessage);
}

void Heavy_ChaffVerb::cVar_NYgwUA9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aR8oMNMC, HV_BINOP_MULTIPLY, 0, m, &cBinop_aR8oMNMC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uKk4rjgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D13TjngW, 0, m, &cDelay_D13TjngW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Wj1TQHDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D13TjngW, 2, m, &cDelay_D13TjngW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9CCk6Sfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aR8oMNMC, HV_BINOP_MULTIPLY, 1, m, &cBinop_aR8oMNMC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aR8oMNMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Wj1TQHDy_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_KUtG2gVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ApNNQMu, HV_BINOP_SUBTRACT, 0, m, &cBinop_7ApNNQMu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_o1xSVXBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gXfmEj9T_sendMessage);
}

void Heavy_ChaffVerb::cSystem_gXfmEj9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_exoHZufZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_FM1utm2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BvgWrgNh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ofTVmWd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ofTVmWd8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZPpFgXKp, 0, m, &cDelay_ZPpFgXKp_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rfKaknlM, 0, m, &sTabread_rfKaknlM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ZPpFgXKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZPpFgXKp, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rfKaknlM, 0, m, &sTabread_rfKaknlM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZPpFgXKp, 0, m, &cDelay_ZPpFgXKp_sendMessage);
}

void Heavy_ChaffVerb::sTabread_rfKaknlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_CG7pfxN8, HV_BINOP_SUBTRACT, 0, m, &cBinop_CG7pfxN8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Vs4tNmww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lcDHjdX3, HV_BINOP_MAX, 0, m, &cBinop_lcDHjdX3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_exoHZufZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vs4tNmww, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vs4tNmww_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7ApNNQMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x2JHfmLC_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rfKaknlM, 0, m, &sTabread_rfKaknlM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x37lPDjE_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HLYQyFoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CG7pfxN8, HV_BINOP_SUBTRACT, 1, m, &cBinop_CG7pfxN8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZPpFgXKp, 2, m, &cDelay_ZPpFgXKp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BvgWrgNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HLYQyFoM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_x2JHfmLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ofTVmWd8, 0, m, &cDelay_ofTVmWd8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZPpFgXKp, 0, m, &cDelay_ZPpFgXKp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Pl9UvwsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_lcDHjdX3, HV_BINOP_MAX, 1, m, &cBinop_lcDHjdX3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lcDHjdX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ApNNQMu, HV_BINOP_SUBTRACT, 1, m, &cBinop_7ApNNQMu_sendMessage);
}

void Heavy_ChaffVerb::cCast_x37lPDjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ofTVmWd8, 0, m, &cDelay_ofTVmWd8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vZu3hYay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ofTVmWd8, 2, m, &cDelay_ofTVmWd8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CG7pfxN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vZu3hYay_sendMessage);
}

void Heavy_ChaffVerb::cCast_xpd0gLag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FM1utm2R, 0, m, &cVar_FM1utm2R_sendMessage);
  cMsg_o1xSVXBg_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_KUtG2gVr, 0, m, &cTabhead_KUtG2gVr_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_gjCYvMPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_urmdW32S, HV_BINOP_SUBTRACT, 0, m, &cBinop_urmdW32S_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4J36Pha6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mX0ykAyL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mX0ykAyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IbxZ8bDL_sendMessage);
}

void Heavy_ChaffVerb::cVar_7JsNZ5tk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qic1OfM8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_oja5cqE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oja5cqE7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y9WDKF9d, 0, m, &cDelay_y9WDKF9d_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_WAVAKt7r, 0, m, &sTabread_WAVAKt7r_sendMessage);
}

void Heavy_ChaffVerb::cDelay_y9WDKF9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y9WDKF9d, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_WAVAKt7r, 0, m, &sTabread_WAVAKt7r_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y9WDKF9d, 0, m, &cDelay_y9WDKF9d_sendMessage);
}

void Heavy_ChaffVerb::sTabread_WAVAKt7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_bh23WgNV, HV_BINOP_SUBTRACT, 0, m, &cBinop_bh23WgNV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_z5dCco2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S1UmaDov, HV_BINOP_MAX, 0, m, &cBinop_S1UmaDov_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IbxZ8bDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z5dCco2X, HV_BINOP_MULTIPLY, 0, m, &cBinop_z5dCco2X_sendMessage);
}

void Heavy_ChaffVerb::cBinop_urmdW32S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uzURYZLZ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_WAVAKt7r, 0, m, &sTabread_WAVAKt7r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pdHaFB4p_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lL3GT6DJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bh23WgNV, HV_BINOP_SUBTRACT, 1, m, &cBinop_bh23WgNV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y9WDKF9d, 2, m, &cDelay_y9WDKF9d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qic1OfM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lL3GT6DJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uzURYZLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oja5cqE7, 0, m, &cDelay_oja5cqE7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y9WDKF9d, 0, m, &cDelay_y9WDKF9d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FnSVR0qW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_S1UmaDov, HV_BINOP_MAX, 1, m, &cBinop_S1UmaDov_sendMessage);
}

void Heavy_ChaffVerb::cBinop_S1UmaDov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_urmdW32S, HV_BINOP_SUBTRACT, 1, m, &cBinop_urmdW32S_sendMessage);
}

void Heavy_ChaffVerb::cCast_pdHaFB4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oja5cqE7, 0, m, &cDelay_oja5cqE7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rz37IN2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oja5cqE7, 2, m, &cDelay_oja5cqE7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bh23WgNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rz37IN2V_sendMessage);
}

void Heavy_ChaffVerb::cCast_WfkzBpxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7JsNZ5tk, 0, m, &cVar_7JsNZ5tk_sendMessage);
  cMsg_4J36Pha6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_gjCYvMPN, 0, m, &cTabhead_gjCYvMPN_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_5OxP1yx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVgJgAah, HV_BINOP_SUBTRACT, 0, m, &cBinop_IVgJgAah_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bmcuX9tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UVoXa25c_sendMessage);
}

void Heavy_ChaffVerb::cSystem_UVoXa25c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_U0nNxuGd_sendMessage);
}

void Heavy_ChaffVerb::cVar_v04riKtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LTGK3cmF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_FBWcFVzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FBWcFVzU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LOL15Bwx, 0, m, &cDelay_LOL15Bwx_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JnCW7j4M, 0, m, &sTabread_JnCW7j4M_sendMessage);
}

void Heavy_ChaffVerb::cDelay_LOL15Bwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LOL15Bwx, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JnCW7j4M, 0, m, &sTabread_JnCW7j4M_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LOL15Bwx, 0, m, &cDelay_LOL15Bwx_sendMessage);
}

void Heavy_ChaffVerb::sTabread_JnCW7j4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_4sFF5IF0, HV_BINOP_SUBTRACT, 0, m, &cBinop_4sFF5IF0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_uye8cHGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P2PnV67D, HV_BINOP_MAX, 0, m, &cBinop_P2PnV67D_sendMessage);
}

void Heavy_ChaffVerb::cBinop_U0nNxuGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uye8cHGP, HV_BINOP_MULTIPLY, 0, m, &cBinop_uye8cHGP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IVgJgAah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tvhULVNt_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JnCW7j4M, 0, m, &sTabread_JnCW7j4M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bg0K1gag_sendMessage);
}

void Heavy_ChaffVerb::cSystem_bR2Eaohh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4sFF5IF0, HV_BINOP_SUBTRACT, 1, m, &cBinop_4sFF5IF0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LOL15Bwx, 2, m, &cDelay_LOL15Bwx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LTGK3cmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bR2Eaohh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tvhULVNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FBWcFVzU, 0, m, &cDelay_FBWcFVzU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LOL15Bwx, 0, m, &cDelay_LOL15Bwx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EDJoFIxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_P2PnV67D, HV_BINOP_MAX, 1, m, &cBinop_P2PnV67D_sendMessage);
}

void Heavy_ChaffVerb::cBinop_P2PnV67D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVgJgAah, HV_BINOP_SUBTRACT, 1, m, &cBinop_IVgJgAah_sendMessage);
}

void Heavy_ChaffVerb::cCast_bg0K1gag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FBWcFVzU, 0, m, &cDelay_FBWcFVzU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gp1lA5TZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FBWcFVzU, 2, m, &cDelay_FBWcFVzU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4sFF5IF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gp1lA5TZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_h86lkzcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v04riKtU, 0, m, &cVar_v04riKtU_sendMessage);
  cMsg_bmcuX9tC_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5OxP1yx2, 0, m, &cTabhead_5OxP1yx2_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_2YpONAO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UJ8WubBN, HV_BINOP_SUBTRACT, 0, m, &cBinop_UJ8WubBN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oJpjTkCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8O86S0jU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8O86S0jU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_dr7FrhVd_sendMessage);
}

void Heavy_ChaffVerb::cVar_0jjqNT8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j6H4gNHB_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_jBgQgC7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jBgQgC7J, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M15XfGBG, 0, m, &cDelay_M15XfGBG_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ftzb4YEe, 0, m, &sTabread_ftzb4YEe_sendMessage);
}

void Heavy_ChaffVerb::cDelay_M15XfGBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M15XfGBG, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ftzb4YEe, 0, m, &sTabread_ftzb4YEe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M15XfGBG, 0, m, &cDelay_M15XfGBG_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ftzb4YEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_bVT6SqqL, HV_BINOP_SUBTRACT, 0, m, &cBinop_bVT6SqqL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ohrPUjUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gOuceqPu, HV_BINOP_MAX, 0, m, &cBinop_gOuceqPu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dr7FrhVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ohrPUjUQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_ohrPUjUQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UJ8WubBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UMkn7Gst_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ftzb4YEe, 0, m, &sTabread_ftzb4YEe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_msNgmQPL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_OI9PMetC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVT6SqqL, HV_BINOP_SUBTRACT, 1, m, &cBinop_bVT6SqqL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M15XfGBG, 2, m, &cDelay_M15XfGBG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_j6H4gNHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OI9PMetC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UMkn7Gst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jBgQgC7J, 0, m, &cDelay_jBgQgC7J_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M15XfGBG, 0, m, &cDelay_M15XfGBG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mJoixUED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_gOuceqPu, HV_BINOP_MAX, 1, m, &cBinop_gOuceqPu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gOuceqPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UJ8WubBN, HV_BINOP_SUBTRACT, 1, m, &cBinop_UJ8WubBN_sendMessage);
}

void Heavy_ChaffVerb::cCast_msNgmQPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jBgQgC7J, 0, m, &cDelay_jBgQgC7J_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IvcHvN1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jBgQgC7J, 2, m, &cDelay_jBgQgC7J_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bVT6SqqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IvcHvN1T_sendMessage);
}

void Heavy_ChaffVerb::cCast_HdpPqcsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0jjqNT8r, 0, m, &cVar_0jjqNT8r_sendMessage);
  cMsg_oJpjTkCa_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2YpONAO6, 0, m, &cTabhead_2YpONAO6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SlyPvEj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wwWkqvVV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wwWkqvVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rpVIUfZq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_oklNCsq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oklNCsq2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pIOQSB4M, 0, m, &cDelay_pIOQSB4M_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oklNCsq2, 0, m, &cDelay_oklNCsq2_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9tYqz89q, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_pIOQSB4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pIOQSB4M, m);
  cMsg_KDwJnFBH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_5CRZiLnY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vholXeaP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_nhARv1Zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ivFRFh1u_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_oNMFCw27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QwRyGczu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oklNCsq2, 2, m, &cDelay_oklNCsq2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mjIcPFqD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ivFRFh1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_oNMFCw27, 0, m, &hTable_oNMFCw27_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rpVIUfZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_nhARv1Zn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KDwJnFBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_oNMFCw27, 0, m, &hTable_oNMFCw27_sendMessage);
}

void Heavy_ChaffVerb::cCast_mjIcPFqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oklNCsq2, 0, m, &cDelay_oklNCsq2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QwRyGczu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_pIOQSB4M, 2, m, &cDelay_pIOQSB4M_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vholXeaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9tYqz89q, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_kxyBg3FY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_N6B8zrOs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_N6B8zrOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7MXEJbDz_sendMessage);
}

void Heavy_ChaffVerb::cDelay_GeJzDG5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GeJzDG5D, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bztv2R9U, 0, m, &cDelay_bztv2R9U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GeJzDG5D, 0, m, &cDelay_GeJzDG5D_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_vtASE6W0, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_bztv2R9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bztv2R9U, m);
  cMsg_pIS3EiDQ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_o9e3fX1X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_s6yTooCf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_AgT5wfJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KwjrBy5p_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_XWWQ7oGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oIeEYTO4_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GeJzDG5D, 2, m, &cDelay_GeJzDG5D_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HhmnTaTN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KwjrBy5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_XWWQ7oGZ, 0, m, &hTable_XWWQ7oGZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7MXEJbDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_AgT5wfJr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pIS3EiDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_XWWQ7oGZ, 0, m, &hTable_XWWQ7oGZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_HhmnTaTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GeJzDG5D, 0, m, &cDelay_GeJzDG5D_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oIeEYTO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bztv2R9U, 2, m, &cDelay_bztv2R9U_sendMessage);
}

void Heavy_ChaffVerb::cMsg_s6yTooCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_vtASE6W0, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_qN5kBhI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DGc7WLW1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DGc7WLW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_AGi8B3zm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Q96iqBnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q96iqBnK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5BnR4jW9, 0, m, &cDelay_5BnR4jW9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q96iqBnK, 0, m, &cDelay_Q96iqBnK_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Y16JGJ4M, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_5BnR4jW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5BnR4jW9, m);
  cMsg_9DacwJqY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_2kZV8iZf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_1YH6eOnt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_NSuphcQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UWRYTSUd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_a8GQeZi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Og7stbH_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q96iqBnK, 2, m, &cDelay_Q96iqBnK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7nJSwRtY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UWRYTSUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_a8GQeZi7, 0, m, &hTable_a8GQeZi7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AGi8B3zm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_NSuphcQS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9DacwJqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_a8GQeZi7, 0, m, &hTable_a8GQeZi7_sendMessage);
}

void Heavy_ChaffVerb::cCast_7nJSwRtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q96iqBnK, 0, m, &cDelay_Q96iqBnK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4Og7stbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_5BnR4jW9, 2, m, &cDelay_5BnR4jW9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1YH6eOnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Y16JGJ4M, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_iFJI3Kgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_O76dTM6z_sendMessage);
}

void Heavy_ChaffVerb::cSystem_O76dTM6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_u9FrnO4U_sendMessage);
}

void Heavy_ChaffVerb::cDelay_J71nXzoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_J71nXzoi, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VZmevt2Q, 0, m, &cDelay_VZmevt2Q_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_J71nXzoi, 0, m, &cDelay_J71nXzoi_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1dxgHgP1, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_VZmevt2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VZmevt2Q, m);
  cMsg_mSiYMOpj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_wpeCK0pJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wYkL9g4C_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_id5wskjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5qgaEAOs_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_It44TaoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MDYnPVnB_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_J71nXzoi, 2, m, &cDelay_J71nXzoi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3swIUXqq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5qgaEAOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_It44TaoQ, 0, m, &hTable_It44TaoQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_u9FrnO4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_id5wskjk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mSiYMOpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_It44TaoQ, 0, m, &hTable_It44TaoQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_3swIUXqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_J71nXzoi, 0, m, &cDelay_J71nXzoi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MDYnPVnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VZmevt2Q, 2, m, &cDelay_VZmevt2Q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wYkL9g4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1dxgHgP1, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_F7rUmkZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_azXGJ5Db, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_sGtGAT5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_m1gS2Xca, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_kfHJG2Fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6GHiMtMt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6GHiMtMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_EjZTNPEn_sendMessage);
}

void Heavy_ChaffVerb::cVar_97QunPUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6cUwqBnX, HV_BINOP_MULTIPLY, 0, m, &cBinop_6cUwqBnX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9feAbdYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LhOw3dXY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_LhOw3dXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tpDLLMNK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_6cUwqBnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_on3TyeH1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_o099PLNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6cUwqBnX, HV_BINOP_MULTIPLY, 1, m, &cBinop_6cUwqBnX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tpDLLMNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_o099PLNB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_on3TyeH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Rm3EdkBR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Rm3EdkBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_AmVVwcC7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_N2JXSvEI, m);
}

void Heavy_ChaffVerb::cBinop_AmVVwcC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LNHrOYYa, m);
}

void Heavy_ChaffVerb::cVar_DX20MxIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_mi3gSZdJ_sendMessage);
}

void Heavy_ChaffVerb::cVar_irzKSqgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kfHJG2Fb_sendMessage);
}

void Heavy_ChaffVerb::cVar_euDv1hrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_y1JvNlyk_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SEFcjWG3, 0, m, &cIf_SEFcjWG3_sendMessage);
}

void Heavy_ChaffVerb::cVar_cAYmo345_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_db0Yzvsr_sendMessage);
}

void Heavy_ChaffVerb::cIf_SEFcjWG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LTvE2itu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_foaqfjHh, 0, m, &cVar_foaqfjHh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_y1JvNlyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SEFcjWG3, 1, m, &cIf_SEFcjWG3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_db0Yzvsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_V9Gqw3pJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_V9Gqw3pJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cfy6Ph7Y, 0, m, &cVar_Cfy6Ph7Y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_o0rLWBM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nFzYOUkP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_nFzYOUkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9Kx510FL_sendMessage);
}

void Heavy_ChaffVerb::cDelay_krBgENcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_krBgENcG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kdszcoJJ, 0, m, &cDelay_kdszcoJJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_krBgENcG, 0, m, &cDelay_krBgENcG_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NZZRa13l, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_kdszcoJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kdszcoJJ, m);
  cMsg_s98bLsjR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Hx2fA0P0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ef83e8v1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_OVr7l9oA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7myNbLIK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_GsOiTsvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mnYfuoUI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_krBgENcG, 2, m, &cDelay_krBgENcG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o1OK6hC1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7myNbLIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_GsOiTsvz, 0, m, &hTable_GsOiTsvz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9Kx510FL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_OVr7l9oA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_s98bLsjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_GsOiTsvz, 0, m, &hTable_GsOiTsvz_sendMessage);
}

void Heavy_ChaffVerb::cCast_o1OK6hC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_krBgENcG, 0, m, &cDelay_krBgENcG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mnYfuoUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kdszcoJJ, 2, m, &cDelay_kdszcoJJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ef83e8v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NZZRa13l, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_vTB1GvGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7aZpItSO, HV_BINOP_SUBTRACT, 0, m, &cBinop_7aZpItSO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5XT5VzgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0NMy7ZER_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0NMy7ZER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LdiZ4E2e_sendMessage);
}

void Heavy_ChaffVerb::cVar_vVy3wVAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lc0jC7k9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_xQBRn5in_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xQBRn5in, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w5qZvUOz, 0, m, &cDelay_w5qZvUOz_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SUZKXQRN, 0, m, &sTabread_SUZKXQRN_sendMessage);
}

void Heavy_ChaffVerb::cDelay_w5qZvUOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_w5qZvUOz, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SUZKXQRN, 0, m, &sTabread_SUZKXQRN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w5qZvUOz, 0, m, &cDelay_w5qZvUOz_sendMessage);
}

void Heavy_ChaffVerb::sTabread_SUZKXQRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_eVDTi0Oy, HV_BINOP_SUBTRACT, 0, m, &cBinop_eVDTi0Oy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_9Vaejsez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeDhfnTv, HV_BINOP_MAX, 0, m, &cBinop_MeDhfnTv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LdiZ4E2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Vaejsez, HV_BINOP_MULTIPLY, 0, m, &cBinop_9Vaejsez_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7aZpItSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mdM7ZhzY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SUZKXQRN, 0, m, &sTabread_SUZKXQRN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8UKK8mDT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CHsqBbgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eVDTi0Oy, HV_BINOP_SUBTRACT, 1, m, &cBinop_eVDTi0Oy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w5qZvUOz, 2, m, &cDelay_w5qZvUOz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Lc0jC7k9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CHsqBbgX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mdM7ZhzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xQBRn5in, 0, m, &cDelay_xQBRn5in_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w5qZvUOz, 0, m, &cDelay_w5qZvUOz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qLKBPB8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeDhfnTv, HV_BINOP_MAX, 1, m, &cBinop_MeDhfnTv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MeDhfnTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7aZpItSO, HV_BINOP_SUBTRACT, 1, m, &cBinop_7aZpItSO_sendMessage);
}

void Heavy_ChaffVerb::cCast_8UKK8mDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xQBRn5in, 0, m, &cDelay_xQBRn5in_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AD06blM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xQBRn5in, 2, m, &cDelay_xQBRn5in_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eVDTi0Oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_AD06blM7_sendMessage);
}

void Heavy_ChaffVerb::cCast_vYnhVugB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vVy3wVAq, 0, m, &cVar_vVy3wVAq_sendMessage);
  cMsg_5XT5VzgY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vTB1GvGl, 0, m, &cTabhead_vTB1GvGl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zRaeG298_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eBR2VaA9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_eBR2VaA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_V4WcTCrv_sendMessage);
}

void Heavy_ChaffVerb::cDelay_LzDoLlnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LzDoLlnR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_E1FhQp3i, 0, m, &cDelay_E1FhQp3i_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LzDoLlnR, 0, m, &cDelay_LzDoLlnR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AsxBkHKU, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_E1FhQp3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E1FhQp3i, m);
  cMsg_LbxpCrEE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_OawvKkDw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wMgi8VXR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_8yp5mgRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TFGgzjjy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_LgT9iNqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wCXvfFFT_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LzDoLlnR, 2, m, &cDelay_LzDoLlnR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wn2TWMrF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TFGgzjjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LgT9iNqQ, 0, m, &hTable_LgT9iNqQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_V4WcTCrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_8yp5mgRT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LbxpCrEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LgT9iNqQ, 0, m, &hTable_LgT9iNqQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_wn2TWMrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LzDoLlnR, 0, m, &cDelay_LzDoLlnR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wCXvfFFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_E1FhQp3i, 2, m, &cDelay_E1FhQp3i_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wMgi8VXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AsxBkHKU, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_q10hbw3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pUg5ZQcx, HV_BINOP_SUBTRACT, 0, m, &cBinop_pUg5ZQcx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_O3lnn6v0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hNM3IvyK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hNM3IvyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_adJoWq4D_sendMessage);
}

void Heavy_ChaffVerb::cVar_La2uLvsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GVRBM0cy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ct1dScD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ct1dScD8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMxFHuA2, 0, m, &cDelay_jMxFHuA2_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_uZ6SVxqP, 0, m, &sTabread_uZ6SVxqP_sendMessage);
}

void Heavy_ChaffVerb::cDelay_jMxFHuA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jMxFHuA2, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_uZ6SVxqP, 0, m, &sTabread_uZ6SVxqP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMxFHuA2, 0, m, &cDelay_jMxFHuA2_sendMessage);
}

void Heavy_ChaffVerb::sTabread_uZ6SVxqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_zjHWK5Xq, HV_BINOP_SUBTRACT, 0, m, &cBinop_zjHWK5Xq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_BCS7E3xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHuFHAHI, HV_BINOP_MAX, 0, m, &cBinop_RHuFHAHI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_adJoWq4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BCS7E3xj, HV_BINOP_MULTIPLY, 0, m, &cBinop_BCS7E3xj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pUg5ZQcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q7ZvRj1l_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_uZ6SVxqP, 0, m, &sTabread_uZ6SVxqP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OsZOvghF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CnUQzsHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjHWK5Xq, HV_BINOP_SUBTRACT, 1, m, &cBinop_zjHWK5Xq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMxFHuA2, 2, m, &cDelay_jMxFHuA2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GVRBM0cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CnUQzsHZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Q7ZvRj1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ct1dScD8, 0, m, &cDelay_ct1dScD8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMxFHuA2, 0, m, &cDelay_jMxFHuA2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ycO7TZs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHuFHAHI, HV_BINOP_MAX, 1, m, &cBinop_RHuFHAHI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RHuFHAHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pUg5ZQcx, HV_BINOP_SUBTRACT, 1, m, &cBinop_pUg5ZQcx_sendMessage);
}

void Heavy_ChaffVerb::cCast_OsZOvghF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ct1dScD8, 0, m, &cDelay_ct1dScD8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5EzqO2SM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ct1dScD8, 2, m, &cDelay_ct1dScD8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zjHWK5Xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5EzqO2SM_sendMessage);
}

void Heavy_ChaffVerb::cCast_7U7fHh18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_La2uLvsX, 0, m, &cVar_La2uLvsX_sendMessage);
  cMsg_O3lnn6v0_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_q10hbw3a, 0, m, &cTabhead_q10hbw3a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_g12qX40I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lGSnF6lx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lGSnF6lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bRF8Ehc7_sendMessage);
}

void Heavy_ChaffVerb::cDelay_C9kd8RNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C9kd8RNI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UUF0djwA, 0, m, &cDelay_UUF0djwA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C9kd8RNI, 0, m, &cDelay_C9kd8RNI_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8bB1UpFy, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_UUF0djwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UUF0djwA, m);
  cMsg_Ccm0fvQG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_jVmI32QN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Gu6BmauM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_9uJWxJbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_otJwFdDO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_um2wrYRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_orNIkNm1_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C9kd8RNI, 2, m, &cDelay_C9kd8RNI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XaenVeVV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_otJwFdDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_um2wrYRw, 0, m, &hTable_um2wrYRw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bRF8Ehc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_9uJWxJbt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ccm0fvQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_um2wrYRw, 0, m, &hTable_um2wrYRw_sendMessage);
}

void Heavy_ChaffVerb::cCast_XaenVeVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C9kd8RNI, 0, m, &cDelay_C9kd8RNI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_orNIkNm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UUF0djwA, 2, m, &cDelay_UUF0djwA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Gu6BmauM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8bB1UpFy, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_DOCSSkCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wywqE2ZD, HV_BINOP_SUBTRACT, 0, m, &cBinop_wywqE2ZD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1bLOa9nA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_l2OgOaDm_sendMessage);
}

void Heavy_ChaffVerb::cSystem_l2OgOaDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2YTnB5Jh_sendMessage);
}

void Heavy_ChaffVerb::cVar_y8QvfIRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k1Z970Ya_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_r36RCa9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_r36RCa9d, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rR5NMt5w, 0, m, &cDelay_rR5NMt5w_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Mn2G4XeJ, 0, m, &sTabread_Mn2G4XeJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_rR5NMt5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rR5NMt5w, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Mn2G4XeJ, 0, m, &sTabread_Mn2G4XeJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rR5NMt5w, 0, m, &cDelay_rR5NMt5w_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Mn2G4XeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_pbcN7Zyk, HV_BINOP_SUBTRACT, 0, m, &cBinop_pbcN7Zyk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_pZNctJiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZNkJsEZ3, HV_BINOP_MAX, 0, m, &cBinop_ZNkJsEZ3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2YTnB5Jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pZNctJiL, HV_BINOP_MULTIPLY, 0, m, &cBinop_pZNctJiL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wywqE2ZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YxMf0d4c_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Mn2G4XeJ, 0, m, &sTabread_Mn2G4XeJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rINVXmCe_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lujYhyRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pbcN7Zyk, HV_BINOP_SUBTRACT, 1, m, &cBinop_pbcN7Zyk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rR5NMt5w, 2, m, &cDelay_rR5NMt5w_sendMessage);
}

void Heavy_ChaffVerb::cMsg_k1Z970Ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lujYhyRQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YxMf0d4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_r36RCa9d, 0, m, &cDelay_r36RCa9d_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rR5NMt5w, 0, m, &cDelay_rR5NMt5w_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ENHgf9YU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZNkJsEZ3, HV_BINOP_MAX, 1, m, &cBinop_ZNkJsEZ3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZNkJsEZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wywqE2ZD, HV_BINOP_SUBTRACT, 1, m, &cBinop_wywqE2ZD_sendMessage);
}

void Heavy_ChaffVerb::cCast_rINVXmCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_r36RCa9d, 0, m, &cDelay_r36RCa9d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KNQZ5SiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_r36RCa9d, 2, m, &cDelay_r36RCa9d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pbcN7Zyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KNQZ5SiV_sendMessage);
}

void Heavy_ChaffVerb::cCast_cg8hoEC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y8QvfIRM, 0, m, &cVar_y8QvfIRM_sendMessage);
  cMsg_1bLOa9nA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_DOCSSkCW, 0, m, &cTabhead_DOCSSkCW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gfIS0wn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UQVsQKHF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_UQVsQKHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QMeDDV2t_sendMessage);
}

void Heavy_ChaffVerb::cDelay_5Kaw9835_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5Kaw9835, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SwNNDQLW, 0, m, &cDelay_SwNNDQLW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5Kaw9835, 0, m, &cDelay_5Kaw9835_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EOxuAuIY, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_SwNNDQLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SwNNDQLW, m);
  cMsg_haqlNkYy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_9dMju0hn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_c1WRNr3w_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_9PLWmVqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EHX3G1q0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_o4jZZY1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c3FpKKaH_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5Kaw9835, 2, m, &cDelay_5Kaw9835_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vm05650M_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EHX3G1q0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_o4jZZY1g, 0, m, &hTable_o4jZZY1g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QMeDDV2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_9PLWmVqe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_haqlNkYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_o4jZZY1g, 0, m, &hTable_o4jZZY1g_sendMessage);
}

void Heavy_ChaffVerb::cCast_Vm05650M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5Kaw9835, 0, m, &cDelay_5Kaw9835_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c3FpKKaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_SwNNDQLW, 2, m, &cDelay_SwNNDQLW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c1WRNr3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EOxuAuIY, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Xsz7uXJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKgygMKl, HV_BINOP_SUBTRACT, 0, m, &cBinop_NKgygMKl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OT7ONSHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BJCvR6zk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_BJCvR6zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YAO6dyUf_sendMessage);
}

void Heavy_ChaffVerb::cVar_TnoMnGNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3J2OsxUj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_m6MlFbcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_m6MlFbcL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z9eL5IlI, 0, m, &cDelay_Z9eL5IlI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pJhzhhBS, 0, m, &sTabread_pJhzhhBS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Z9eL5IlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Z9eL5IlI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pJhzhhBS, 0, m, &sTabread_pJhzhhBS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z9eL5IlI, 0, m, &cDelay_Z9eL5IlI_sendMessage);
}

void Heavy_ChaffVerb::sTabread_pJhzhhBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lwuDu1vN, HV_BINOP_SUBTRACT, 0, m, &cBinop_lwuDu1vN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_R2ptISsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JjQPOEEq, HV_BINOP_MAX, 0, m, &cBinop_JjQPOEEq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YAO6dyUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R2ptISsU, HV_BINOP_MULTIPLY, 0, m, &cBinop_R2ptISsU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NKgygMKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NL7eNQ3J_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pJhzhhBS, 0, m, &sTabread_pJhzhhBS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lkoMmkKf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_BeheXBFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lwuDu1vN, HV_BINOP_SUBTRACT, 1, m, &cBinop_lwuDu1vN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z9eL5IlI, 2, m, &cDelay_Z9eL5IlI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3J2OsxUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BeheXBFm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NL7eNQ3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6MlFbcL, 0, m, &cDelay_m6MlFbcL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z9eL5IlI, 0, m, &cDelay_Z9eL5IlI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fhdyTPPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_JjQPOEEq, HV_BINOP_MAX, 1, m, &cBinop_JjQPOEEq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JjQPOEEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKgygMKl, HV_BINOP_SUBTRACT, 1, m, &cBinop_NKgygMKl_sendMessage);
}

void Heavy_ChaffVerb::cCast_lkoMmkKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6MlFbcL, 0, m, &cDelay_m6MlFbcL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_taqbBcHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6MlFbcL, 2, m, &cDelay_m6MlFbcL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lwuDu1vN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_taqbBcHR_sendMessage);
}

void Heavy_ChaffVerb::cCast_AtMNOY6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TnoMnGNh, 0, m, &cVar_TnoMnGNh_sendMessage);
  cMsg_OT7ONSHf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Xsz7uXJG, 0, m, &cTabhead_Xsz7uXJG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_psRka7U7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HXgF0UJJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HXgF0UJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Kb6uA85l_sendMessage);
}

void Heavy_ChaffVerb::cDelay_3iokE1wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3iokE1wj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_n5JwE6Ok, 0, m, &cDelay_n5JwE6Ok_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3iokE1wj, 0, m, &cDelay_3iokE1wj_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KzcEh0cu, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_n5JwE6Ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n5JwE6Ok, m);
  cMsg_w45ck0Tk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_LgppBygD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_OAUtsu8H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_U3kIWgHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TNZSoy1b_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_EReTiHZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YESWz8fi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3iokE1wj, 2, m, &cDelay_3iokE1wj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WvERWzjF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TNZSoy1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_EReTiHZ1, 0, m, &hTable_EReTiHZ1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Kb6uA85l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_U3kIWgHj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_w45ck0Tk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_EReTiHZ1, 0, m, &hTable_EReTiHZ1_sendMessage);
}

void Heavy_ChaffVerb::cCast_WvERWzjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3iokE1wj, 0, m, &cDelay_3iokE1wj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YESWz8fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_n5JwE6Ok, 2, m, &cDelay_n5JwE6Ok_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OAUtsu8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KzcEh0cu, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_owRzuOw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KcNFhBYm, HV_BINOP_SUBTRACT, 0, m, &cBinop_KcNFhBYm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_q7sfYPHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xeao7Nta_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Xeao7Nta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZsrADDtB_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZHvubGhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HHNCeKsj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_SnsW5H9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SnsW5H9v, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hLdIvfws, 0, m, &cDelay_hLdIvfws_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_m8BHiEq3, 0, m, &sTabread_m8BHiEq3_sendMessage);
}

void Heavy_ChaffVerb::cDelay_hLdIvfws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hLdIvfws, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_m8BHiEq3, 0, m, &sTabread_m8BHiEq3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hLdIvfws, 0, m, &cDelay_hLdIvfws_sendMessage);
}

void Heavy_ChaffVerb::sTabread_m8BHiEq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_eLxGKmcV, HV_BINOP_SUBTRACT, 0, m, &cBinop_eLxGKmcV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_LYeXtCSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aD2AimRs, HV_BINOP_MAX, 0, m, &cBinop_aD2AimRs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZsrADDtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LYeXtCSZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_LYeXtCSZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KcNFhBYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xZwyl3Xn_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_m8BHiEq3, 0, m, &sTabread_m8BHiEq3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iY2aBVYO_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9j9ZYz4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eLxGKmcV, HV_BINOP_SUBTRACT, 1, m, &cBinop_eLxGKmcV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hLdIvfws, 2, m, &cDelay_hLdIvfws_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HHNCeKsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9j9ZYz4Y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xZwyl3Xn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SnsW5H9v, 0, m, &cDelay_SnsW5H9v_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hLdIvfws, 0, m, &cDelay_hLdIvfws_sendMessage);
}

void Heavy_ChaffVerb::cMsg_edFq261l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_aD2AimRs, HV_BINOP_MAX, 1, m, &cBinop_aD2AimRs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aD2AimRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KcNFhBYm, HV_BINOP_SUBTRACT, 1, m, &cBinop_KcNFhBYm_sendMessage);
}

void Heavy_ChaffVerb::cCast_iY2aBVYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SnsW5H9v, 0, m, &cDelay_SnsW5H9v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6QWuWGDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SnsW5H9v, 2, m, &cDelay_SnsW5H9v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eLxGKmcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6QWuWGDz_sendMessage);
}

void Heavy_ChaffVerb::cCast_ev1vnmWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZHvubGhI, 0, m, &cVar_ZHvubGhI_sendMessage);
  cMsg_q7sfYPHq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_owRzuOw0, 0, m, &cTabhead_owRzuOw0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_imOFFq9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xJf7gCcY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xJf7gCcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zyzVqeCX_sendMessage);
}

void Heavy_ChaffVerb::cDelay_CiaqsZkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CiaqsZkU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g6RmIu5F, 0, m, &cDelay_g6RmIu5F_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CiaqsZkU, 0, m, &cDelay_CiaqsZkU_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JxQ4H07J, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_g6RmIu5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_g6RmIu5F, m);
  cMsg_wZks5pNo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_8irHC4iA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Aw04N9ZL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_2gVCepuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_btL4vmv9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_548ftrN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_59CGREoo_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CiaqsZkU, 2, m, &cDelay_CiaqsZkU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hlfIpeww_sendMessage);
}

void Heavy_ChaffVerb::cMsg_btL4vmv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_548ftrN1, 0, m, &hTable_548ftrN1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zyzVqeCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_2gVCepuW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wZks5pNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_548ftrN1, 0, m, &hTable_548ftrN1_sendMessage);
}

void Heavy_ChaffVerb::cCast_hlfIpeww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CiaqsZkU, 0, m, &cDelay_CiaqsZkU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_59CGREoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_g6RmIu5F, 2, m, &cDelay_g6RmIu5F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Aw04N9ZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JxQ4H07J, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_wTppF3lG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wm4O0sL0, HV_BINOP_SUBTRACT, 0, m, &cBinop_Wm4O0sL0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r2owkYnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nZcejjPK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_nZcejjPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wRKdrJso_sendMessage);
}

void Heavy_ChaffVerb::cVar_zQ2cLko9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B7Hcrs0k_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_sYXkKMwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sYXkKMwG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0pbf47T, 0, m, &cDelay_h0pbf47T_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_swWfKNoP, 0, m, &sTabread_swWfKNoP_sendMessage);
}

void Heavy_ChaffVerb::cDelay_h0pbf47T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h0pbf47T, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_swWfKNoP, 0, m, &sTabread_swWfKNoP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0pbf47T, 0, m, &cDelay_h0pbf47T_sendMessage);
}

void Heavy_ChaffVerb::sTabread_swWfKNoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Ia3OQ22P, HV_BINOP_SUBTRACT, 0, m, &cBinop_Ia3OQ22P_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_hA6hjOx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PIH8zAQf, HV_BINOP_MAX, 0, m, &cBinop_PIH8zAQf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wRKdrJso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hA6hjOx8, HV_BINOP_MULTIPLY, 0, m, &cBinop_hA6hjOx8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Wm4O0sL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9orDBQHg_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_swWfKNoP, 0, m, &sTabread_swWfKNoP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N8cFVLAy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_eOqZaPFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ia3OQ22P, HV_BINOP_SUBTRACT, 1, m, &cBinop_Ia3OQ22P_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0pbf47T, 2, m, &cDelay_h0pbf47T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B7Hcrs0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eOqZaPFG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9orDBQHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sYXkKMwG, 0, m, &cDelay_sYXkKMwG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0pbf47T, 0, m, &cDelay_h0pbf47T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_l7sjOE6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_PIH8zAQf, HV_BINOP_MAX, 1, m, &cBinop_PIH8zAQf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PIH8zAQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wm4O0sL0, HV_BINOP_SUBTRACT, 1, m, &cBinop_Wm4O0sL0_sendMessage);
}

void Heavy_ChaffVerb::cCast_N8cFVLAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sYXkKMwG, 0, m, &cDelay_sYXkKMwG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SqGIEkLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sYXkKMwG, 2, m, &cDelay_sYXkKMwG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ia3OQ22P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SqGIEkLv_sendMessage);
}

void Heavy_ChaffVerb::cCast_DLad9U8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zQ2cLko9, 0, m, &cVar_zQ2cLko9_sendMessage);
  cMsg_r2owkYnT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wTppF3lG, 0, m, &cTabhead_wTppF3lG_sendMessage);
}

void Heavy_ChaffVerb::cVar_foaqfjHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_97QunPUQ, 0, m, &cVar_97QunPUQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LRvFyzdq, 0, m, &cVar_LRvFyzdq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oA9LNXyk, 0, m, &cVar_oA9LNXyk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lLfICOrO, 0, m, &cVar_lLfICOrO_sendMessage);
}

void Heavy_ChaffVerb::cVar_Cfy6Ph7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_xhZ7Yu8W_sendMessage);
}

void Heavy_ChaffVerb::cPack_t38m1xB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_oTevwxgp, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_LRvFyzdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DoNxcx1a, HV_BINOP_MULTIPLY, 0, m, &cBinop_DoNxcx1a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5vu8sjKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Fu4XRyAk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Fu4XRyAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bfcpV2CX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_DoNxcx1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_T9uD0XfH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_N3WAPR2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DoNxcx1a, HV_BINOP_MULTIPLY, 1, m, &cBinop_DoNxcx1a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bfcpV2CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_N3WAPR2i_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T9uD0XfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KuwH7BgA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KuwH7BgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nFAoXcHN_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_m4Sqb3Fg, m);
}

void Heavy_ChaffVerb::cBinop_nFAoXcHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_YHzmwJRR, m);
}

void Heavy_ChaffVerb::cVar_oA9LNXyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3cCjnbrL, HV_BINOP_MULTIPLY, 0, m, &cBinop_3cCjnbrL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ydDh4amu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_egIPm4cP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_egIPm4cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zZq72oqU_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_3cCjnbrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Jk1c28G6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ufAc4CBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3cCjnbrL, HV_BINOP_MULTIPLY, 1, m, &cBinop_3cCjnbrL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zZq72oqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ufAc4CBo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Jk1c28G6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HogPvksm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HogPvksm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9Dx7YwDn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_T4Z1e7Pw, m);
}

void Heavy_ChaffVerb::cBinop_9Dx7YwDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qy1RPXpi, m);
}

void Heavy_ChaffVerb::cVar_lLfICOrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7nCWqV70, HV_BINOP_MULTIPLY, 0, m, &cBinop_7nCWqV70_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Z9t159zu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wT1NZE0O_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wT1NZE0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yT03D8DI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_7nCWqV70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DGM0sPHw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KnrTls2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7nCWqV70, HV_BINOP_MULTIPLY, 1, m, &cBinop_7nCWqV70_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yT03D8DI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KnrTls2v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DGM0sPHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hcIoNgSy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hcIoNgSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_96v8FBqG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xoziU3W5, m);
}

void Heavy_ChaffVerb::cBinop_96v8FBqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Eo9i292A, m);
}

void Heavy_ChaffVerb::cBinop_EjZTNPEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_sGtGAT5V, 0, m, &cPack_sGtGAT5V_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LTvE2itu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_foaqfjHh, 0, m, &cVar_foaqfjHh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xhZ7Yu8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_t38m1xB2, 0, m, &cPack_t38m1xB2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mi3gSZdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_F7rUmkZo, 0, m, &cPack_F7rUmkZo_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_AvrTX39w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_4IQTVe6u_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_4IQTVe6u_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kDgwXg2b_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_1D5gvrUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1D5gvrUH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1D5gvrUH, 0, m, &cDelay_1D5gvrUH_sendMessage);
  cSwitchcase_hAj0ddyj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_kDgwXg2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4IQTVe6u_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1D5gvrUH, 0, m, &cDelay_1D5gvrUH_sendMessage);
  cSwitchcase_hAj0ddyj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_nnIdO4Mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zOO5N3WU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zOO5N3WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7fgd1N8O_sendMessage);
}

void Heavy_ChaffVerb::cVar_aa8uhMDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJfkHgvc, HV_BINOP_MULTIPLY, 0, m, &cBinop_sJfkHgvc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4IQTVe6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1D5gvrUH, 0, m, &cDelay_1D5gvrUH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EzZ8HkiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1D5gvrUH, 2, m, &cDelay_1D5gvrUH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7fgd1N8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJfkHgvc, HV_BINOP_MULTIPLY, 1, m, &cBinop_sJfkHgvc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sJfkHgvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_EzZ8HkiG_sendMessage);
}

void Heavy_ChaffVerb::cVar_AMVmFkpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_4ZmIKL4f_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_50rgpKrk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Ypvm3vqO_sendMessage);
}

void Heavy_ChaffVerb::cVar_4VnwJYoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZMEl0VjE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Fv0GE5Ln, 0, m, &cIf_Fv0GE5Ln_sendMessage);
}

void Heavy_ChaffVerb::cUnop_DFjlbVKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ctL4CrjG, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_ctL4CrjG_sendMessage);
}

void Heavy_ChaffVerb::cUnop_97yrK6bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ctL4CrjG, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_ctL4CrjG_sendMessage);
}

void Heavy_ChaffVerb::cIf_Fv0GE5Ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_97yrK6bs_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_DFjlbVKY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ZMEl0VjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fv0GE5Ln, 1, m, &cIf_Fv0GE5Ln_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Jxb8NEYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JuJVwthd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JuJVwthd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_caWcDoSR_sendMessage);
}

void Heavy_ChaffVerb::cDelay_DVS5u9cE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DVS5u9cE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xS5fJ2jF, 0, m, &cDelay_xS5fJ2jF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DVS5u9cE, 0, m, &cDelay_DVS5u9cE_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_R7yICHDe, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_xS5fJ2jF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xS5fJ2jF, m);
  cMsg_APOBV94N_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_QJFEO1jK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_QseHwqLK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_SWC0eQZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9SPw92FM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_hb1HOJja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vrqAeSrv_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DVS5u9cE, 2, m, &cDelay_DVS5u9cE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YheuaIVB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9SPw92FM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_hb1HOJja, 0, m, &hTable_hb1HOJja_sendMessage);
}

void Heavy_ChaffVerb::cBinop_caWcDoSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_SWC0eQZT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_APOBV94N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_hb1HOJja, 0, m, &hTable_hb1HOJja_sendMessage);
}

void Heavy_ChaffVerb::cCast_YheuaIVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DVS5u9cE, 0, m, &cDelay_DVS5u9cE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vrqAeSrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xS5fJ2jF, 2, m, &cDelay_xS5fJ2jF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QseHwqLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_R7yICHDe, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_vd7LwTv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fsrtILvs, HV_BINOP_SUBTRACT, 0, m, &cBinop_fsrtILvs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EDM8Qs2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1ucYamnb_sendMessage);
}

void Heavy_ChaffVerb::cSystem_1ucYamnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kPO9Qomq_sendMessage);
}

void Heavy_ChaffVerb::cVar_PPZCHPaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_stR0Jm2Z_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_3LHNw9qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3LHNw9qv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DKbBTw0s, 0, m, &cDelay_DKbBTw0s_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OJBXKnEe, 0, m, &sTabread_OJBXKnEe_sendMessage);
}

void Heavy_ChaffVerb::cDelay_DKbBTw0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DKbBTw0s, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OJBXKnEe, 0, m, &sTabread_OJBXKnEe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DKbBTw0s, 0, m, &cDelay_DKbBTw0s_sendMessage);
}

void Heavy_ChaffVerb::sTabread_OJBXKnEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_W0HMG76r, HV_BINOP_SUBTRACT, 0, m, &cBinop_W0HMG76r_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_a4fXsdX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JFPihXUj, HV_BINOP_MAX, 0, m, &cBinop_JFPihXUj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kPO9Qomq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a4fXsdX6, HV_BINOP_MULTIPLY, 0, m, &cBinop_a4fXsdX6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fsrtILvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3b3WS7IW_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OJBXKnEe, 0, m, &sTabread_OJBXKnEe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6sBujWn2_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZonIt3HC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W0HMG76r, HV_BINOP_SUBTRACT, 1, m, &cBinop_W0HMG76r_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DKbBTw0s, 2, m, &cDelay_DKbBTw0s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_stR0Jm2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZonIt3HC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3b3WS7IW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LHNw9qv, 0, m, &cDelay_3LHNw9qv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DKbBTw0s, 0, m, &cDelay_DKbBTw0s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KRQ2gb1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_JFPihXUj, HV_BINOP_MAX, 1, m, &cBinop_JFPihXUj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JFPihXUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fsrtILvs, HV_BINOP_SUBTRACT, 1, m, &cBinop_fsrtILvs_sendMessage);
}

void Heavy_ChaffVerb::cCast_6sBujWn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LHNw9qv, 0, m, &cDelay_3LHNw9qv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DKqyMYbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LHNw9qv, 2, m, &cDelay_3LHNw9qv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_W0HMG76r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DKqyMYbL_sendMessage);
}

void Heavy_ChaffVerb::cCast_oO4lgoyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PPZCHPaJ, 0, m, &cVar_PPZCHPaJ_sendMessage);
  cMsg_EDM8Qs2S_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vd7LwTv4, 0, m, &cTabhead_vd7LwTv4_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_6gfRPZ2h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jZ5NsYSP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_jZ5NsYSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2JFkrG7e_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_nRVBSSSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRScYxnE, HV_BINOP_ADD, 0, m, &cBinop_gRScYxnE_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_JMfHzZyn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dmY2znvm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_dmY2znvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_niM06KQ6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_qZG9sv45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ib7EIMIY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MdKI7wIJ_sendMessage);
}

void Heavy_ChaffVerb::cVar_RAlphUC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uc9nvINl, 0, m, &cVar_uc9nvINl_sendMessage);
}

void Heavy_ChaffVerb::cVar_uc9nvINl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z7K4L2xC, HV_BINOP_ADD, 0, m, &cBinop_z7K4L2xC_sendMessage);
}

void Heavy_ChaffVerb::cVar_MLXTCCNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lo6mqpJN, HV_BINOP_ADD, 0, m, &cBinop_lo6mqpJN_sendMessage);
}

void Heavy_ChaffVerb::cVar_Mkw3vVGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NxCehDgY_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_TQBz5o43, 0, m, &cIf_TQBz5o43_sendMessage);
}

void Heavy_ChaffVerb::cUnop_tvq4kPHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lo6mqpJN, HV_BINOP_ADD, 1, m, &cBinop_lo6mqpJN_sendMessage);
}

void Heavy_ChaffVerb::cUnop_WddMZsxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lo6mqpJN, HV_BINOP_ADD, 1, m, &cBinop_lo6mqpJN_sendMessage);
}

void Heavy_ChaffVerb::cIf_TQBz5o43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_WddMZsxl_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_tvq4kPHr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_NxCehDgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TQBz5o43, 1, m, &cIf_TQBz5o43_sendMessage);
}

void Heavy_ChaffVerb::cVar_yzhbuYPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hbb79JyR_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_IbyA0xbd, 0, m, &cIf_IbyA0xbd_sendMessage);
}

void Heavy_ChaffVerb::cUnop_nGWB7G2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_R23f0Hwx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_Ayj8t99t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_R23f0Hwx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_IbyA0xbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_Ayj8t99t_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_nGWB7G2n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_hbb79JyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IbyA0xbd, 1, m, &cIf_IbyA0xbd_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_R23f0Hwx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yLCWoWTA, 0, m, &cSlice_yLCWoWTA_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lrucTbd6, 0, m, &cSlice_lrucTbd6_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_awkDN10A_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DR0Ynkbg_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_yLCWoWTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_V4PjMotn, 0, m, &cVar_V4PjMotn_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_V4PjMotn, 0, m, &cVar_V4PjMotn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_lrucTbd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_3sK9qNLL, HV_BINOP_NEQ, 1, m, &cBinop_3sK9qNLL_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_V4PjMotn, 1, m, &cVar_V4PjMotn_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_3sK9qNLL, HV_BINOP_NEQ, 1, m, &cBinop_3sK9qNLL_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_V4PjMotn, 1, m, &cVar_V4PjMotn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_V4PjMotn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TaNeec5M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IfQp8ZHf_sendMessage);
}

void Heavy_ChaffVerb::cIf_tSIvkysO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7AMyunAZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rrrid1ck_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_7AMyunAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3sK9qNLL, HV_BINOP_NEQ, 1, m, &cBinop_3sK9qNLL_sendMessage);
}

void Heavy_ChaffVerb::cCast_Rrrid1ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V4PjMotn, 0, m, &cVar_V4PjMotn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3sK9qNLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tSIvkysO, 1, m, &cIf_tSIvkysO_sendMessage);
}

void Heavy_ChaffVerb::cCast_awkDN10A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3sK9qNLL, HV_BINOP_NEQ, 0, m, &cBinop_3sK9qNLL_sendMessage);
}

void Heavy_ChaffVerb::cCast_DR0Ynkbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tSIvkysO, 0, m, &cIf_tSIvkysO_sendMessage);
}

void Heavy_ChaffVerb::cIf_zVNMz1Kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_RAlphUC6, 0, m, &cVar_RAlphUC6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_AZEwPb2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_zVNMz1Kh, 0, m, &cIf_zVNMz1Kh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_TmBM4xcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_zVNMz1Kh, 0, m, &cIf_zVNMz1Kh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_JH1UhyZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_zVNMz1Kh, 0, m, &cIf_zVNMz1Kh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_LsaiPGyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_qZG9sv45, 0, m, &cVar_qZG9sv45_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_sN5DYtHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MLXTCCNe, 0, m, &cVar_MLXTCCNe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3vput0P1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AZEwPb2f, 1, m, &cIf_AZEwPb2f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GXwbNZiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_JH1UhyZK, 1, m, &cIf_JH1UhyZK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bRTnzPrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AZEwPb2f, 1, m, &cIf_AZEwPb2f_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_TmBM4xcT, 1, m, &cIf_TmBM4xcT_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JH1UhyZK, 1, m, &cIf_JH1UhyZK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_THERKaV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nRVBSSSP, 0, m, &cVar_nRVBSSSP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qZx4uLHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_THERKaV0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_niM06KQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_qZG9sv45, 0, m, &cVar_qZG9sv45_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ctL4CrjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g5CLYQOs, HV_BINOP_MULTIPLY, 0, m, &cBinop_g5CLYQOs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ypvm3vqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ctL4CrjG, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_ctL4CrjG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YIrWeIx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TmBM4xcT, 1, m, &cIf_TmBM4xcT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lo6mqpJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0iEtEzrU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_INkvLTn2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IfEbSbqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oFcUla5F, 0, m, &cVar_oFcUla5F_sendMessage);
}

void Heavy_ChaffVerb::cCast_0iEtEzrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IfEbSbqg, HV_BINOP_ADD, 1, m, &cBinop_IfEbSbqg_sendMessage);
}

void Heavy_ChaffVerb::cCast_INkvLTn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RAlphUC6, 0, m, &cVar_RAlphUC6_sendMessage);
}

void Heavy_ChaffVerb::cCast_TaNeec5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bRTnzPrl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_IfQp8ZHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KvUSitgh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_PH5Zkxzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_irzKSqgx, 0, m, &cVar_irzKSqgx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_g5CLYQOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TmBM4xcT, 0, m, &cIf_TmBM4xcT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SfEP95Wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JH1UhyZK, 0, m, &cIf_JH1UhyZK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_X4pitM90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_H2zCWmrL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_SfEP95Wl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4ZmIKL4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_LQJ69bOY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LQJ69bOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_X4pitM90_sendMessage);
}

void Heavy_ChaffVerb::cBinop_50rgpKrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AMVmFkpT, 1, m, &cVar_AMVmFkpT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MYVfFUYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NYgwUA9N, 0, m, &cVar_NYgwUA9N_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OSpDxYWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aa8uhMDb, 0, m, &cVar_aa8uhMDb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2JFkrG7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RAlphUC6, 0, m, &cVar_RAlphUC6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gRScYxnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jvRWF5HR, HV_BINOP_MULTIPLY, 0, m, &cBinop_jvRWF5HR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jvRWF5HR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LsaiPGyZ, 0, m, &cIf_LsaiPGyZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_se8z84Pb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IfEbSbqg, HV_BINOP_ADD, 0, m, &cBinop_IfEbSbqg_sendMessage);
}

void Heavy_ChaffVerb::cCast_ib7EIMIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_se8z84Pb, HV_BINOP_ADD, 1, m, &cBinop_se8z84Pb_sendMessage);
}

void Heavy_ChaffVerb::cCast_MdKI7wIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RAlphUC6, 0, m, &cVar_RAlphUC6_sendMessage);
}

void Heavy_ChaffVerb::cCast_h4O7xYPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6gfRPZ2h_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_nm3QxKp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zVNMz1Kh, 1, m, &cIf_zVNMz1Kh_sendMessage);
}

void Heavy_ChaffVerb::cCast_NaZ8a1zZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jvRWF5HR, HV_BINOP_MULTIPLY, 1, m, &cBinop_jvRWF5HR_sendMessage);
}

void Heavy_ChaffVerb::cCast_6JNOsG5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nRVBSSSP, 0, m, &cVar_nRVBSSSP_sendMessage);
}

void Heavy_ChaffVerb::cCast_gcLRhZEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JMfHzZyn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_OBU4B7X6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LsaiPGyZ, 1, m, &cIf_LsaiPGyZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_Q4LhFi8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRScYxnE, HV_BINOP_ADD, 1, m, &cBinop_gRScYxnE_sendMessage);
}

void Heavy_ChaffVerb::cCast_JOrTeNJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nRVBSSSP, 0, m, &cVar_nRVBSSSP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Xvlt9p8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_se8z84Pb, HV_BINOP_ADD, 0, m, &cBinop_se8z84Pb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z7K4L2xC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xvlt9p8p, HV_BINOP_MULTIPLY, 0, m, &cBinop_Xvlt9p8p_sendMessage);
}

void Heavy_ChaffVerb::cCast_OjQqrW6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xvlt9p8p, HV_BINOP_MULTIPLY, 1, m, &cBinop_Xvlt9p8p_sendMessage);
}

void Heavy_ChaffVerb::cCast_VvAMzdwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RAlphUC6, 0, m, &cVar_RAlphUC6_sendMessage);
}

void Heavy_ChaffVerb::cCast_Zd83rg6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z7K4L2xC, HV_BINOP_ADD, 1, m, &cBinop_z7K4L2xC_sendMessage);
}

void Heavy_ChaffVerb::cCast_Y8ZXzpPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RAlphUC6, 0, m, &cVar_RAlphUC6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2HiEziAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TaNeec5M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IfQp8ZHf_sendMessage);
}

void Heavy_ChaffVerb::cReceive_1O1F6qTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o0rLWBM6_sendMessage(_c, 0, m);
  cMsg_zRaeG298_sendMessage(_c, 0, m);
  cMsg_g12qX40I_sendMessage(_c, 0, m);
  cMsg_gfIS0wn8_sendMessage(_c, 0, m);
  cMsg_psRka7U7_sendMessage(_c, 0, m);
  cMsg_imOFFq9i_sendMessage(_c, 0, m);
  cMsg_Ml9wlwsm_sendMessage(_c, 0, m);
  cMsg_SlyPvEj3_sendMessage(_c, 0, m);
  cMsg_kxyBg3FY_sendMessage(_c, 0, m);
  cMsg_qN5kBhI0_sendMessage(_c, 0, m);
  cMsg_iFJI3Kgu_sendMessage(_c, 0, m);
  cMsg_9feAbdYk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_97QunPUQ, 0, m, &cVar_97QunPUQ_sendMessage);
  cMsg_5vu8sjKg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LRvFyzdq, 0, m, &cVar_LRvFyzdq_sendMessage);
  cMsg_ydDh4amu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oA9LNXyk, 0, m, &cVar_oA9LNXyk_sendMessage);
  cMsg_Z9t159zu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lLfICOrO, 0, m, &cVar_lLfICOrO_sendMessage);
  cMsg_ZcrcqhSG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lSjhJZX2, 0, m, &cVar_lSjhJZX2_sendMessage);
  cMsg_Opzsexs7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NYgwUA9N, 0, m, &cVar_NYgwUA9N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DX20MxIJ, 0, m, &cVar_DX20MxIJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_irzKSqgx, 0, m, &cVar_irzKSqgx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_euDv1hrK, 0, m, &cVar_euDv1hrK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cAYmo345, 0, m, &cVar_cAYmo345_sendMessage);
  cMsg_nnIdO4Mn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_aa8uhMDb, 0, m, &cVar_aa8uhMDb_sendMessage);
  cMsg_Jxb8NEYK_sendMessage(_c, 0, m);
  cSwitchcase_Ml155X1x_onMessage(_c, NULL, 0, m, NULL);
  cMsg_2JFkrG7e_sendMessage(_c, 0, m);
  cMsg_2HiEziAl_sendMessage(_c, 0, m);
  cMsg_niM06KQ6_sendMessage(_c, 0, m);
  cSwitchcase_AvrTX39w_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_jvJOZKyY, 0, m, &cVar_jvJOZKyY_sendMessage);
  cMsg_QWAad5vj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DEQEjUaB, 0, m, &cVar_DEQEjUaB_sendMessage);
  cMsg_MOXoG7ib_sendMessage(_c, 0, m);
  cMsg_Pl9UvwsG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FM1utm2R, 0, m, &cVar_FM1utm2R_sendMessage);
  cMsg_o1xSVXBg_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_KUtG2gVr, 0, m, &cTabhead_KUtG2gVr_sendMessage);
  cMsg_FnSVR0qW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7JsNZ5tk, 0, m, &cVar_7JsNZ5tk_sendMessage);
  cMsg_4J36Pha6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_gjCYvMPN, 0, m, &cTabhead_gjCYvMPN_sendMessage);
  cMsg_EDJoFIxN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_v04riKtU, 0, m, &cVar_v04riKtU_sendMessage);
  cMsg_bmcuX9tC_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5OxP1yx2, 0, m, &cTabhead_5OxP1yx2_sendMessage);
  cMsg_mJoixUED_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0jjqNT8r, 0, m, &cVar_0jjqNT8r_sendMessage);
  cMsg_oJpjTkCa_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2YpONAO6, 0, m, &cTabhead_2YpONAO6_sendMessage);
  cMsg_qLKBPB8L_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vVy3wVAq, 0, m, &cVar_vVy3wVAq_sendMessage);
  cMsg_5XT5VzgY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vTB1GvGl, 0, m, &cTabhead_vTB1GvGl_sendMessage);
  cMsg_ycO7TZs1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_La2uLvsX, 0, m, &cVar_La2uLvsX_sendMessage);
  cMsg_O3lnn6v0_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_q10hbw3a, 0, m, &cTabhead_q10hbw3a_sendMessage);
  cMsg_ENHgf9YU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_y8QvfIRM, 0, m, &cVar_y8QvfIRM_sendMessage);
  cMsg_1bLOa9nA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_DOCSSkCW, 0, m, &cTabhead_DOCSSkCW_sendMessage);
  cMsg_fhdyTPPc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TnoMnGNh, 0, m, &cVar_TnoMnGNh_sendMessage);
  cMsg_OT7ONSHf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Xsz7uXJG, 0, m, &cTabhead_Xsz7uXJG_sendMessage);
  cMsg_edFq261l_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZHvubGhI, 0, m, &cVar_ZHvubGhI_sendMessage);
  cMsg_q7sfYPHq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_owRzuOw0, 0, m, &cTabhead_owRzuOw0_sendMessage);
  cMsg_l7sjOE6a_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zQ2cLko9, 0, m, &cVar_zQ2cLko9_sendMessage);
  cMsg_r2owkYnT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wTppF3lG, 0, m, &cTabhead_wTppF3lG_sendMessage);
  cMsg_KRQ2gb1v_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PPZCHPaJ, 0, m, &cVar_PPZCHPaJ_sendMessage);
  cMsg_EDM8Qs2S_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vd7LwTv4, 0, m, &cTabhead_vd7LwTv4_sendMessage);
}

void Heavy_ChaffVerb::cReceive_DnSMCQa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_MYVfFUYt_sendMessage);
}

void Heavy_ChaffVerb::cReceive_G1Ndn83f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yzhbuYPc, 0, m, &cVar_yzhbuYPc_sendMessage);
}

void Heavy_ChaffVerb::cReceive_DVMAavCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4VnwJYoe, 0, m, &cVar_4VnwJYoe_sendMessage);
}

void Heavy_ChaffVerb::cReceive_S0v48UNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g5CLYQOs, HV_BINOP_MULTIPLY, 1, m, &cBinop_g5CLYQOs_sendMessage);
}

void Heavy_ChaffVerb::cReceive_cOGbNAD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zd83rg6t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y8ZXzpPS_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JcH5wWHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OjQqrW6q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VvAMzdwh_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Nd4IY5Nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MLXTCCNe, 0, m, &cVar_MLXTCCNe_sendMessage);
}

void Heavy_ChaffVerb::cReceive_GzmhsDvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sN5DYtHD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Mkw3vVGY, 0, m, &cVar_Mkw3vVGY_sendMessage);
}

void Heavy_ChaffVerb::cReceive_pkNWiGW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_OSpDxYWs_sendMessage);
}

void Heavy_ChaffVerb::cReceive_azvQhyOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q4LhFi8o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JOrTeNJ1_sendMessage);
}

void Heavy_ChaffVerb::cReceive_thjm6SAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NaZ8a1zZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6JNOsG5w_sendMessage);
}

void Heavy_ChaffVerb::cReceive_977bYG3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OBU4B7X6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gcLRhZEQ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_PhilGpqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6ZTrghAQ, m);
}

void Heavy_ChaffVerb::cReceive_aDsVRz9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_M7NhQ6RK, m);
}

void Heavy_ChaffVerb::cReceive_WcE6IlTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DX20MxIJ, 0, m, &cVar_DX20MxIJ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_k8AIPn6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_PH5Zkxzd_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Na18ZR6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LlAA3JdI, 0, m, &cVar_LlAA3JdI_sendMessage);
}

void Heavy_ChaffVerb::cReceive_cRd0ECzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cUkoo3aw, 0, m, &cVar_cUkoo3aw_sendMessage);
}

void Heavy_ChaffVerb::cReceive_pZFu88rQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lSjhJZX2, 0, m, &cVar_lSjhJZX2_sendMessage);
}

void Heavy_ChaffVerb::cReceive_0YA6dVWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qRDt9ji2, m);
}

void Heavy_ChaffVerb::cReceive_TaQxwRN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vpo016UC, m);
}

void Heavy_ChaffVerb::cReceive_eacOeBD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a4fXsdX6, HV_BINOP_MULTIPLY, 1, m, &cBinop_a4fXsdX6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oO4lgoyv_sendMessage);
}

void Heavy_ChaffVerb::cReceive_xscYC6H7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nm3QxKp9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h4O7xYPL_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_7HVtj4CL, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_HVPAUopZ, VOf(Bf4));
    __hv_line_f(&sLine_h8v9UHnn, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_ftU7Uwc5, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_ANp2JNvR, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_dscb5kI6, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_R89a959p, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_JsBf97q1, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_UR9PZRT4, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_KEGHBg61, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_NKvnNPuT, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_KEAa3I2E, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_CBm7JdWF, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_CvNN9v6O, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_Lb5hipas, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_PwcRmY1B, VIf(I0));
    __hv_varread_f(&sVarf_gnFROSqg, VOf(Bf2));
    __hv_rpole_f(&sRPole_Z8H8AxIY, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_pKOIkqKp, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_MkT9IYOz, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_qRDt9ji2, VOf(Bf1));
    __hv_tabread_f(&sTabread_OJBXKnEe, VOf(Bf5));
    __hv_varread_f(&sVarf_vpo016UC, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_R7yICHDe, VIf(Bf9));
    __hv_varread_f(&sVarf_M7NhQ6RK, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_rfKaknlM, VOf(Bf9));
    __hv_varread_f(&sVarf_N2JXSvEI, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_LNHrOYYa, VOf(Bf2));
    __hv_rpole_f(&sRPole_vxZVhBLt, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_oTevwxgp, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_m1gS2Xca, VOf(Bf2));
    __hv_tabread_f(&sTabread_SUZKXQRN, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_uZ6SVxqP, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_Mn2G4XeJ, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_pJhzhhBS, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_swWfKNoP, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_m8BHiEq3, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_NZZRa13l, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_AsxBkHKU, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_8bB1UpFy, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_EOxuAuIY, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_KzcEh0cu, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_JxQ4H07J, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_WAVAKt7r, VOf(Bf9));
    __hv_varread_f(&sVarf_m4Sqb3Fg, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_YHzmwJRR, VOf(Bf3));
    __hv_rpole_f(&sRPole_aJ7GvkAJ, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_JnCW7j4M, VOf(Bf3));
    __hv_varread_f(&sVarf_T4Z1e7Pw, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_Qy1RPXpi, VOf(Bf12));
    __hv_rpole_f(&sRPole_DV4TeETt, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_ftzb4YEe, VOf(Bf12));
    __hv_varread_f(&sVarf_xoziU3W5, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_Eo9i292A, VOf(Bf11));
    __hv_rpole_f(&sRPole_uOavXcxN, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_9tYqz89q, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_vtASE6W0, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_Y16JGJ4M, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_1dxgHgP1, VIf(Bf11));
    __hv_line_f(&sLine_azXGJ5Db, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_6ZTrghAQ, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
